#!/usr/bin/env python
# -*- coding: utf-8 -*-

import argparse
import os
import pysam
from collections import OrderedDict
from datetime import datetime

from pynnotator import settings
from subprocess import call
toolname = 'merge'


class Merge(object):
    def __init__(self, vcffile=None):

        self.vcffile = vcffile

        self.filename = os.path.splitext(os.path.basename(str(vcffile)))[0]

        self.basedir = os.getcwd()

        # create folder merge if it doesn't exists
        if not os.path.exists('merge'):
            os.makedirs('merge')
        # enter inside folder
        os.chdir('merge')

    def run(self):
        tstart = datetime.now()
        print(tstart, 'Starting merge: ', self.vcffile)

        self.merge()

        tend = datetime.now()
        annotation_time = tend - tstart
        print(tend, 'Finished merge, it took: ', annotation_time)

        # merge VCF Files with VariantAnnotator

    def merge(self):

        # print(BASE_DIR)

        files = ['../snpeff/snpeff.output.vcf', '../vep/vep.output.sorted.vcf', '../snpsift/snpsift.final.vcf']
        for file in files:
            command = 'bgzip {}'.format(file)
            call(command, shell=True)
            command = 'tabix -p vcf {}.gz'.format(file)
            call(command, shell=True)


        config = open('config.toml', 'w')
        config.write("""[[annotation]]
file="{}/snpsift/snpsift.final.vcf.gz"
fields = ["VARTYPE", "SNP", "MNP", "INS", "DEL", "MIXED", "HOM", "HET"]
ops=["first", "first", "first", "first", "first", "first", "first", "first"]

[[annotation]]
file="{}/snpeff/snpeff.output.vcf.gz"
fields = ["ANN"]
names = ["snpeff_eff"]
ops=["first"]

[[annotation]]
file="{}/vep/vep.output.sorted.vcf.gz"
fields = ["CSQ"]
names = ["vep_csq"]
ops=["first"]


        """.format(self.basedir, 
            self.basedir, 
            self.basedir))

        # self.basedir, 
        #     settings.data_dir, settings.dbsnp_file, 
        #     settings.data_dir, settings.clinvar_file, 
        #     settings.data_dir, 
        #     settings.data_dir,
        #     settings.data_dir,
        #     settings.data_dir,
        #     self.basedir, 
        #     self.basedir,
        #     settings.data_dir, settings.data_dir

        config.close()
        command = '{}/vcfanno/vcfanno_linux64 -p {} config.toml ../{} > ../annotation.final.vcf'.format(settings.libs_dir, settings.vcfanno_cores, self.vcffile)
        call(command,shell=True)

if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='MERGE all VCF Files from previous methods.')
    parser.add_argument('-i', dest='vcffile', required=True, metavar='example.vcf', help='a VCF file to be annotated')

    args = parser.parse_args()

    merge = Merge(args.vcffile)
    merge.run()

#remove data dependency
# [[annotation]]
# file="{}/dbsnp/{}"
# fields = ["ID", "RS", "RSPOS", "RV", "VP", "GENEINFO", "dbSNPBuildID", "SAO", "SSR", "WGT", "VC", "PM", "TPA", "PMC", "S3D", "SLO", "NSF", "NSM", "NSN", "REF", "SYN", "U3", "U5", "ASS", "DSS", "INT", "R3", "R5", "OTH", "CFL", "ASP", "MUT", "VLD", "G5A", "G5", "HD", "GNO", "KGPhase1", "KGPhase3", "CDA", "LSD", "MTP", "OM", "NOC", "WTD", "NOV", "NC", "CAF", "COMMON", "TOPMED"]
# ops=["first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first"]

# [[annotation]]
# file="{}/dbsnp/{}"
# fields = ["AF_ESP", "AF_EXAC", "AF_TGP", "ALLELEID", "CLNDN", "CLNDNINCL", "CLNDISDB", "CLNDISDBINCL", "CLNHGVS", "CLNREVSTAT", "CLNSIG", "CLNSIGCONF", "CLNSIGINCL", "CLNVC", "CLNVCSO", "CLNVI", "DBVARID", "GENEINFO", "MC", "ORIGIN", "RS", "SSR", ]
# ops=["first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first"]

# [[annotation]]
# file="{}/1000genomes/ALL.wgs.phase3_shapeit2_mvncall_integrated_v5b.20130502.sites.vcf.gz"
# fields = ["CIEND", "CIPOS", "CS", "END", "IMPRECISE", "MC", "MEINFO", "MEND", "MLEN", "MSTART", "SVLEN", "SVTYPE", "TSD", "AC", "AF", "NS", "AN", "EAS_AF", "EUR_AF", "AFR_AF", "AMR_AF", "SAS_AF", "DP", "AA", "VT", "EX_TARGET", "MULTI_ALLELIC", "OLD_VARIANT"]
# ops=["first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first", "first"]

# [[annotation]]
# file="{}/decipher/HI_Predictions_Version3.bed.gz"
# names=["HI_PREDICTION"]
# columns=[4]
# ops=["uniq"]

# [[annotation]]
# file="{}/ensembl/homo_sapiens_clinically_associated.vcf.gz"
# names = ["ensembl_clin_ClinVar_201706", "ensembl_clin_dbSNP_150", "ensembl_clin_HGMD", "ensembl_clin_PhenCode", "ensembl_clin_COSMIC_81", "ensembl_clin_ESP_20141103", "ensembl_clin_TSA", "ensembl_clin_E_Cited", "ensembl_clin_E_Multiple_observations", "ensembl_clin_E_Freq", "ensembl_clin_E_Hapmap", "ensembl_clin_E_Phenotype_or_Disease", "ensembl_clin_E_ESP", "ensembl_clin_E_1000G", "ensembl_clin_E_ExAC", "ensembl_clin_CLIN_risk_factor", "ensembl_clin_CLIN_protective", "ensembl_clin_CLIN_confers_sensitivity", "ensembl_clin_CLIN_other", "ensembl_clin_CLIN_drug_response", "ensembl_clin_CLIN_uncertain_significance", "ensembl_clin_CLIN_benign", "ensembl_clin_CLIN_likely_pathogenic", "ensembl_clin_CLIN_pathogenic", "ensembl_clin_CLIN_likely_benign", "ensembl_clin_CLIN_histocompatibility", "ensembl_clin_CLIN_not_provided", "ensembl_clin_CLIN_association", "ensembl_clin_MA", "ensembl_clin_MAF", "ensembl_clin_MAC", "ensembl_clin_AA"]
# fields = ["ClinVar_201706", "dbSNP_150", "HGMD", "PhenCode", "COSMIC_81", "ESP_20141103", "TSA", "E_Cited", "E_Multiple_observations", "E_Freq", "E_Hapmap", "E_Phenotype_or_Disease", "E_ESP", "E_1000G", "E_ExAC", "CLIN_risk_factor", "CLIN_protective", "CLIN_confers_sensitivity", "CLIN_other", "CLIN_drug_response", "CLIN_uncertain_significance", "CLIN_benign", "CLIN_likely_pathogenic", "CLIN_pathogenic", "CLIN_likely_benign", "CLIN_histocompatibility", "CLIN_not_provided", "CLIN_association", "MA", "MAF", "MAC", "AA"]
# ops=["first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first"]

# [[annotation]]
# file="{}/ensembl/homo_sapiens_phenotype_associated.vcf.gz"
# names = ["ensembl_phen_ClinVar_201706","ensembl_phen_dbSNP_150","ensembl_phen_HGMD","ensembl_phen_PhenCode","ensembl_phen_COSMIC_81","ensembl_phen_ESP_20141103","ensembl_phen_TSA","ensembl_phen_E_Cited","ensembl_phen_E_Multiple_observations","ensembl_phen_E_Freq","ensembl_phen_E_Hapmap","ensembl_phen_E_Phenotype_or_Disease","ensembl_phen_E_ESP","ensembl_phen_E_1000G","ensembl_phen_E_ExAC","ensembl_phen_CLIN_risk_factor","ensembl_phen_CLIN_protective","ensembl_phen_CLIN_confers_sensitivity","ensembl_phen_CLIN_other","ensembl_phen_CLIN_drug_response","ensembl_phen_CLIN_uncertain_significance","ensembl_phen_CLIN_benign","ensembl_phen_CLIN_likely_pathogenic","ensembl_phen_CLIN_pathogenic","ensembl_phen_CLIN_likely_benign","ensembl_phen_CLIN_histocompatibility","ensembl_phen_CLIN_not_provided","ensembl_phen_CLIN_association","ensembl_phen_MA","ensembl_phen_MAF","ensembl_phen_MAC","ensembl_phen_AA"]
# fields = ["ClinVar_201706", "dbSNP_150", "HGMD", "PhenCode", "COSMIC_81", "ESP_20141103", "TSA", "E_Cited", "E_Multiple_observations", "E_Freq", "E_Hapmap", "E_Phenotype_or_Disease", "E_ESP", "E_1000G", "E_ExAC", "CLIN_risk_factor", "CLIN_protective", "CLIN_confers_sensitivity", "CLIN_other", "CLIN_drug_response", "CLIN_uncertain_significance", "CLIN_benign", "CLIN_likely_pathogenic", "CLIN_pathogenic", "CLIN_likely_benign", "CLIN_histocompatibility", "CLIN_not_provided", "CLIN_association", "MA", "MAF", "MAC", "AA"]
# ops=["first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first"]



#remove gnomad annotation
# [[annotation]]
# file="{}/gnomad/gnomad.exomes.r2.1.sites.vcf.gz"
# names = ["gnomad_ex_ab_hist_alt_bin_freq","gnomad_ex_AC","gnomad_ex_AC_afr","gnomad_ex_AC_afr_female","gnomad_ex_AC_afr_male","gnomad_ex_AC_amr","gnomad_ex_AC_amr_female","gnomad_ex_AC_amr_male","gnomad_ex_AC_asj","gnomad_ex_AC_asj_female","gnomad_ex_AC_asj_male","gnomad_ex_AC_eas","gnomad_ex_AC_eas_female","gnomad_ex_AC_eas_jpn","gnomad_ex_AC_eas_kor","gnomad_ex_AC_eas_male","gnomad_ex_AC_eas_oea","gnomad_ex_AC_female","gnomad_ex_AC_fin","gnomad_ex_AC_fin_female","gnomad_ex_AC_fin_male","gnomad_ex_AC_male","gnomad_ex_AC_nfe","gnomad_ex_AC_nfe_bgr","gnomad_ex_AC_nfe_est","gnomad_ex_AC_nfe_female","gnomad_ex_AC_nfe_male","gnomad_ex_AC_nfe_nwe","gnomad_ex_AC_nfe_onf","gnomad_ex_AC_nfe_seu","gnomad_ex_AC_nfe_swe","gnomad_ex_AC_oth","gnomad_ex_AC_oth_female","gnomad_ex_AC_oth_male","gnomad_ex_AC_popmax","gnomad_ex_AC_raw","gnomad_ex_AC_sas","gnomad_ex_AC_sas_female","gnomad_ex_AC_sas_male","gnomad_ex_AF","gnomad_ex_AF_afr","gnomad_ex_AF_afr_female","gnomad_ex_AF_afr_male","gnomad_ex_AF_amr","gnomad_ex_AF_amr_female","gnomad_ex_AF_amr_male","gnomad_ex_AF_asj","gnomad_ex_AF_asj_female","gnomad_ex_AF_asj_male","gnomad_ex_AF_eas","gnomad_ex_AF_eas_female","gnomad_ex_AF_eas_jpn","gnomad_ex_AF_eas_kor","gnomad_ex_AF_eas_male","gnomad_ex_AF_eas_oea","gnomad_ex_AF_female","gnomad_ex_AF_fin","gnomad_ex_AF_fin_female","gnomad_ex_AF_fin_male","gnomad_ex_AF_male","gnomad_ex_AF_nfe","gnomad_ex_AF_nfe_bgr","gnomad_ex_AF_nfe_est","gnomad_ex_AF_nfe_female","gnomad_ex_AF_nfe_male","gnomad_ex_AF_nfe_nwe","gnomad_ex_AF_nfe_onf","gnomad_ex_AF_nfe_seu","gnomad_ex_AF_nfe_swe","gnomad_ex_AF_oth","gnomad_ex_AF_oth_female","gnomad_ex_AF_oth_male","gnomad_ex_AF_popmax","gnomad_ex_AF_raw","gnomad_ex_AF_sas","gnomad_ex_AF_sas_female","gnomad_ex_AF_sas_male","gnomad_ex_age_hist_het_bin_freq","gnomad_ex_age_hist_het_n_larger","gnomad_ex_age_hist_het_n_smaller","gnomad_ex_age_hist_hom_bin_freq","gnomad_ex_age_hist_hom_n_larger","gnomad_ex_age_hist_hom_n_smaller","gnomad_ex_allele_type","gnomad_ex_AN","gnomad_ex_AN_afr","gnomad_ex_AN_afr_female","gnomad_ex_AN_afr_male","gnomad_ex_AN_amr","gnomad_ex_AN_amr_female","gnomad_ex_AN_amr_male","gnomad_ex_AN_asj","gnomad_ex_AN_asj_female","gnomad_ex_AN_asj_male","gnomad_ex_AN_eas","gnomad_ex_AN_eas_female","gnomad_ex_AN_eas_jpn","gnomad_ex_AN_eas_kor","gnomad_ex_AN_eas_male","gnomad_ex_AN_eas_oea","gnomad_ex_AN_female","gnomad_ex_AN_fin","gnomad_ex_AN_fin_female","gnomad_ex_AN_fin_male","gnomad_ex_AN_male","gnomad_ex_AN_nfe","gnomad_ex_AN_nfe_bgr","gnomad_ex_AN_nfe_est","gnomad_ex_AN_nfe_female","gnomad_ex_AN_nfe_male","gnomad_ex_AN_nfe_nwe","gnomad_ex_AN_nfe_onf","gnomad_ex_AN_nfe_seu","gnomad_ex_AN_nfe_swe","gnomad_ex_AN_oth","gnomad_ex_AN_oth_female","gnomad_ex_AN_oth_male","gnomad_ex_AN_popmax","gnomad_ex_AN_raw","gnomad_ex_AN_sas","gnomad_ex_AN_sas_female","gnomad_ex_AN_sas_male","gnomad_ex_BaseQRankSum","gnomad_ex_ClippingRankSum","gnomad_ex_controls_AC","gnomad_ex_controls_AC_afr","gnomad_ex_controls_AC_afr_female","gnomad_ex_controls_AC_afr_male","gnomad_ex_controls_AC_amr","gnomad_ex_controls_AC_amr_female","gnomad_ex_controls_AC_amr_male","gnomad_ex_controls_AC_asj","gnomad_ex_controls_AC_asj_female","gnomad_ex_controls_AC_asj_male","gnomad_ex_controls_AC_eas","gnomad_ex_controls_AC_eas_female","gnomad_ex_controls_AC_eas_jpn","gnomad_ex_controls_AC_eas_kor","gnomad_ex_controls_AC_eas_male","gnomad_ex_controls_AC_eas_oea","gnomad_ex_controls_AC_female","gnomad_ex_controls_AC_fin","gnomad_ex_controls_AC_fin_female","gnomad_ex_controls_AC_fin_male","gnomad_ex_controls_AC_male","gnomad_ex_controls_AC_nfe","gnomad_ex_controls_AC_nfe_bgr","gnomad_ex_controls_AC_nfe_est","gnomad_ex_controls_AC_nfe_female","gnomad_ex_controls_AC_nfe_male","gnomad_ex_controls_AC_nfe_nwe","gnomad_ex_controls_AC_nfe_onf","gnomad_ex_controls_AC_nfe_seu","gnomad_ex_controls_AC_nfe_swe","gnomad_ex_controls_AC_oth","gnomad_ex_controls_AC_oth_female","gnomad_ex_controls_AC_oth_male","gnomad_ex_controls_AC_popmax","gnomad_ex_controls_AC_raw","gnomad_ex_controls_AC_sas","gnomad_ex_controls_AC_sas_female","gnomad_ex_controls_AC_sas_male","gnomad_ex_controls_AF","gnomad_ex_controls_AF_afr","gnomad_ex_controls_AF_afr_female","gnomad_ex_controls_AF_afr_male","gnomad_ex_controls_AF_amr","gnomad_ex_controls_AF_amr_female","gnomad_ex_controls_AF_amr_male","gnomad_ex_controls_AF_asj","gnomad_ex_controls_AF_asj_female","gnomad_ex_controls_AF_asj_male","gnomad_ex_controls_AF_eas","gnomad_ex_controls_AF_eas_female","gnomad_ex_controls_AF_eas_jpn","gnomad_ex_controls_AF_eas_kor","gnomad_ex_controls_AF_eas_male","gnomad_ex_controls_AF_eas_oea","gnomad_ex_controls_AF_female","gnomad_ex_controls_AF_fin","gnomad_ex_controls_AF_fin_female","gnomad_ex_controls_AF_fin_male","gnomad_ex_controls_AF_male","gnomad_ex_controls_AF_nfe","gnomad_ex_controls_AF_nfe_bgr","gnomad_ex_controls_AF_nfe_est","gnomad_ex_controls_AF_nfe_female","gnomad_ex_controls_AF_nfe_male","gnomad_ex_controls_AF_nfe_nwe","gnomad_ex_controls_AF_nfe_onf","gnomad_ex_controls_AF_nfe_seu","gnomad_ex_controls_AF_nfe_swe","gnomad_ex_controls_AF_oth","gnomad_ex_controls_AF_oth_female","gnomad_ex_controls_AF_oth_male","gnomad_ex_controls_AF_popmax","gnomad_ex_controls_AF_raw","gnomad_ex_controls_AF_sas","gnomad_ex_controls_AF_sas_female","gnomad_ex_controls_AF_sas_male","gnomad_ex_controls_AN","gnomad_ex_controls_AN_afr","gnomad_ex_controls_AN_afr_female","gnomad_ex_controls_AN_afr_male","gnomad_ex_controls_AN_amr","gnomad_ex_controls_AN_amr_female","gnomad_ex_controls_AN_amr_male","gnomad_ex_controls_AN_asj","gnomad_ex_controls_AN_asj_female","gnomad_ex_controls_AN_asj_male","gnomad_ex_controls_AN_eas","gnomad_ex_controls_AN_eas_female","gnomad_ex_controls_AN_eas_jpn","gnomad_ex_controls_AN_eas_kor","gnomad_ex_controls_AN_eas_male","gnomad_ex_controls_AN_eas_oea","gnomad_ex_controls_AN_female","gnomad_ex_controls_AN_fin","gnomad_ex_controls_AN_fin_female","gnomad_ex_controls_AN_fin_male","gnomad_ex_controls_AN_male","gnomad_ex_controls_AN_nfe","gnomad_ex_controls_AN_nfe_bgr","gnomad_ex_controls_AN_nfe_est","gnomad_ex_controls_AN_nfe_female","gnomad_ex_controls_AN_nfe_male","gnomad_ex_controls_AN_nfe_nwe","gnomad_ex_controls_AN_nfe_onf","gnomad_ex_controls_AN_nfe_seu","gnomad_ex_controls_AN_nfe_swe","gnomad_ex_controls_AN_oth","gnomad_ex_controls_AN_oth_female","gnomad_ex_controls_AN_oth_male","gnomad_ex_controls_AN_popmax","gnomad_ex_controls_AN_raw","gnomad_ex_controls_AN_sas","gnomad_ex_controls_AN_sas_female","gnomad_ex_controls_AN_sas_male","gnomad_ex_controls_faf95","gnomad_ex_controls_faf95_afr","gnomad_ex_controls_faf95_amr","gnomad_ex_controls_faf95_eas","gnomad_ex_controls_faf95_nfe","gnomad_ex_controls_faf95_sas","gnomad_ex_controls_faf99","gnomad_ex_controls_faf99_afr","gnomad_ex_controls_faf99_amr","gnomad_ex_controls_faf99_eas","gnomad_ex_controls_faf99_nfe","gnomad_ex_controls_faf99_sas","gnomad_ex_controls_nhomalt","gnomad_ex_controls_nhomalt_afr","gnomad_ex_controls_nhomalt_afr_female","gnomad_ex_controls_nhomalt_afr_male","gnomad_ex_controls_nhomalt_amr","gnomad_ex_controls_nhomalt_amr_female","gnomad_ex_controls_nhomalt_amr_male","gnomad_ex_controls_nhomalt_asj","gnomad_ex_controls_nhomalt_asj_female","gnomad_ex_controls_nhomalt_asj_male","gnomad_ex_controls_nhomalt_eas","gnomad_ex_controls_nhomalt_eas_female","gnomad_ex_controls_nhomalt_eas_jpn","gnomad_ex_controls_nhomalt_eas_kor","gnomad_ex_controls_nhomalt_eas_male","gnomad_ex_controls_nhomalt_eas_oea","gnomad_ex_controls_nhomalt_female","gnomad_ex_controls_nhomalt_fin","gnomad_ex_controls_nhomalt_fin_female","gnomad_ex_controls_nhomalt_fin_male","gnomad_ex_controls_nhomalt_male","gnomad_ex_controls_nhomalt_nfe","gnomad_ex_controls_nhomalt_nfe_bgr","gnomad_ex_controls_nhomalt_nfe_est","gnomad_ex_controls_nhomalt_nfe_female","gnomad_ex_controls_nhomalt_nfe_male","gnomad_ex_controls_nhomalt_nfe_nwe","gnomad_ex_controls_nhomalt_nfe_onf","gnomad_ex_controls_nhomalt_nfe_seu","gnomad_ex_controls_nhomalt_nfe_swe","gnomad_ex_controls_nhomalt_oth","gnomad_ex_controls_nhomalt_oth_female","gnomad_ex_controls_nhomalt_oth_male","gnomad_ex_controls_nhomalt_popmax","gnomad_ex_controls_nhomalt_raw","gnomad_ex_controls_nhomalt_sas","gnomad_ex_controls_nhomalt_sas_female","gnomad_ex_controls_nhomalt_sas_male","gnomad_ex_controls_popmax","gnomad_ex_decoy","gnomad_ex_DP","gnomad_ex_dp_hist_all_bin_freq","gnomad_ex_dp_hist_all_n_larger","gnomad_ex_dp_hist_alt_bin_freq","gnomad_ex_dp_hist_alt_n_larger","gnomad_ex_faf95","gnomad_ex_faf95_afr","gnomad_ex_faf95_amr","gnomad_ex_faf95_eas","gnomad_ex_faf95_nfe","gnomad_ex_faf95_sas","gnomad_ex_faf99","gnomad_ex_faf99_afr","gnomad_ex_faf99_amr","gnomad_ex_faf99_eas","gnomad_ex_faf99_nfe","gnomad_ex_faf99_sas","gnomad_ex_FS","gnomad_ex_gq_hist_all_bin_freq","gnomad_ex_gq_hist_alt_bin_freq","gnomad_ex_has_star","gnomad_ex_InbreedingCoeff","gnomad_ex_lcr","gnomad_ex_MQ","gnomad_ex_MQRankSum","gnomad_ex_n_alt_alleles","gnomad_ex_nhomalt","gnomad_ex_nhomalt_afr","gnomad_ex_nhomalt_afr_female","gnomad_ex_nhomalt_afr_male","gnomad_ex_nhomalt_amr","gnomad_ex_nhomalt_amr_female","gnomad_ex_nhomalt_amr_male","gnomad_ex_nhomalt_asj","gnomad_ex_nhomalt_asj_female","gnomad_ex_nhomalt_asj_male","gnomad_ex_nhomalt_eas","gnomad_ex_nhomalt_eas_female","gnomad_ex_nhomalt_eas_jpn","gnomad_ex_nhomalt_eas_kor","gnomad_ex_nhomalt_eas_male","gnomad_ex_nhomalt_eas_oea","gnomad_ex_nhomalt_female","gnomad_ex_nhomalt_fin","gnomad_ex_nhomalt_fin_female","gnomad_ex_nhomalt_fin_male","gnomad_ex_nhomalt_male","gnomad_ex_nhomalt_nfe","gnomad_ex_nhomalt_nfe_bgr","gnomad_ex_nhomalt_nfe_est","gnomad_ex_nhomalt_nfe_female","gnomad_ex_nhomalt_nfe_male","gnomad_ex_nhomalt_nfe_nwe","gnomad_ex_nhomalt_nfe_onf","gnomad_ex_nhomalt_nfe_seu","gnomad_ex_nhomalt_nfe_swe","gnomad_ex_nhomalt_oth","gnomad_ex_nhomalt_oth_female","gnomad_ex_nhomalt_oth_male","gnomad_ex_nhomalt_popmax","gnomad_ex_nhomalt_raw","gnomad_ex_nhomalt_sas","gnomad_ex_nhomalt_sas_female","gnomad_ex_nhomalt_sas_male","gnomad_ex_non_cancer_AC","gnomad_ex_non_cancer_AC_afr","gnomad_ex_non_cancer_AC_afr_female","gnomad_ex_non_cancer_AC_afr_male","gnomad_ex_non_cancer_AC_amr","gnomad_ex_non_cancer_AC_amr_female","gnomad_ex_non_cancer_AC_amr_male","gnomad_ex_non_cancer_AC_asj","gnomad_ex_non_cancer_AC_asj_female","gnomad_ex_non_cancer_AC_asj_male","gnomad_ex_non_cancer_AC_eas","gnomad_ex_non_cancer_AC_eas_female","gnomad_ex_non_cancer_AC_eas_jpn","gnomad_ex_non_cancer_AC_eas_kor","gnomad_ex_non_cancer_AC_eas_male","gnomad_ex_non_cancer_AC_eas_oea","gnomad_ex_non_cancer_AC_female","gnomad_ex_non_cancer_AC_fin","gnomad_ex_non_cancer_AC_fin_female","gnomad_ex_non_cancer_AC_fin_male","gnomad_ex_non_cancer_AC_male","gnomad_ex_non_cancer_AC_nfe","gnomad_ex_non_cancer_AC_nfe_bgr","gnomad_ex_non_cancer_AC_nfe_est","gnomad_ex_non_cancer_AC_nfe_female","gnomad_ex_non_cancer_AC_nfe_male","gnomad_ex_non_cancer_AC_nfe_nwe","gnomad_ex_non_cancer_AC_nfe_onf","gnomad_ex_non_cancer_AC_nfe_seu","gnomad_ex_non_cancer_AC_nfe_swe","gnomad_ex_non_cancer_AC_oth","gnomad_ex_non_cancer_AC_oth_female","gnomad_ex_non_cancer_AC_oth_male","gnomad_ex_non_cancer_AC_popmax","gnomad_ex_non_cancer_AC_raw","gnomad_ex_non_cancer_AC_sas","gnomad_ex_non_cancer_AC_sas_female","gnomad_ex_non_cancer_AC_sas_male","gnomad_ex_non_cancer_AF","gnomad_ex_non_cancer_AF_afr","gnomad_ex_non_cancer_AF_afr_female","gnomad_ex_non_cancer_AF_afr_male","gnomad_ex_non_cancer_AF_amr","gnomad_ex_non_cancer_AF_amr_female","gnomad_ex_non_cancer_AF_amr_male","gnomad_ex_non_cancer_AF_asj","gnomad_ex_non_cancer_AF_asj_female","gnomad_ex_non_cancer_AF_asj_male","gnomad_ex_non_cancer_AF_eas","gnomad_ex_non_cancer_AF_eas_female","gnomad_ex_non_cancer_AF_eas_jpn","gnomad_ex_non_cancer_AF_eas_kor","gnomad_ex_non_cancer_AF_eas_male","gnomad_ex_non_cancer_AF_eas_oea","gnomad_ex_non_cancer_AF_female","gnomad_ex_non_cancer_AF_fin","gnomad_ex_non_cancer_AF_fin_female","gnomad_ex_non_cancer_AF_fin_male","gnomad_ex_non_cancer_AF_male","gnomad_ex_non_cancer_AF_nfe","gnomad_ex_non_cancer_AF_nfe_bgr","gnomad_ex_non_cancer_AF_nfe_est","gnomad_ex_non_cancer_AF_nfe_female","gnomad_ex_non_cancer_AF_nfe_male","gnomad_ex_non_cancer_AF_nfe_nwe","gnomad_ex_non_cancer_AF_nfe_onf","gnomad_ex_non_cancer_AF_nfe_seu","gnomad_ex_non_cancer_AF_nfe_swe","gnomad_ex_non_cancer_AF_oth","gnomad_ex_non_cancer_AF_oth_female","gnomad_ex_non_cancer_AF_oth_male","gnomad_ex_non_cancer_AF_popmax","gnomad_ex_non_cancer_AF_raw","gnomad_ex_non_cancer_AF_sas","gnomad_ex_non_cancer_AF_sas_female","gnomad_ex_non_cancer_AF_sas_male","gnomad_ex_non_cancer_AN","gnomad_ex_non_cancer_AN_afr","gnomad_ex_non_cancer_AN_afr_female","gnomad_ex_non_cancer_AN_afr_male","gnomad_ex_non_cancer_AN_amr","gnomad_ex_non_cancer_AN_amr_female","gnomad_ex_non_cancer_AN_amr_male","gnomad_ex_non_cancer_AN_asj","gnomad_ex_non_cancer_AN_asj_female","gnomad_ex_non_cancer_AN_asj_male","gnomad_ex_non_cancer_AN_eas","gnomad_ex_non_cancer_AN_eas_female","gnomad_ex_non_cancer_AN_eas_jpn","gnomad_ex_non_cancer_AN_eas_kor","gnomad_ex_non_cancer_AN_eas_male","gnomad_ex_non_cancer_AN_eas_oea","gnomad_ex_non_cancer_AN_female","gnomad_ex_non_cancer_AN_fin","gnomad_ex_non_cancer_AN_fin_female","gnomad_ex_non_cancer_AN_fin_male","gnomad_ex_non_cancer_AN_male","gnomad_ex_non_cancer_AN_nfe","gnomad_ex_non_cancer_AN_nfe_bgr","gnomad_ex_non_cancer_AN_nfe_est","gnomad_ex_non_cancer_AN_nfe_female","gnomad_ex_non_cancer_AN_nfe_male","gnomad_ex_non_cancer_AN_nfe_nwe","gnomad_ex_non_cancer_AN_nfe_onf","gnomad_ex_non_cancer_AN_nfe_seu","gnomad_ex_non_cancer_AN_nfe_swe","gnomad_ex_non_cancer_AN_oth","gnomad_ex_non_cancer_AN_oth_female","gnomad_ex_non_cancer_AN_oth_male","gnomad_ex_non_cancer_AN_popmax","gnomad_ex_non_cancer_AN_raw","gnomad_ex_non_cancer_AN_sas","gnomad_ex_non_cancer_AN_sas_female","gnomad_ex_non_cancer_AN_sas_male","gnomad_ex_non_cancer_faf95","gnomad_ex_non_cancer_faf95_afr","gnomad_ex_non_cancer_faf95_amr","gnomad_ex_non_cancer_faf95_eas","gnomad_ex_non_cancer_faf95_nfe","gnomad_ex_non_cancer_faf95_sas","gnomad_ex_non_cancer_faf99","gnomad_ex_non_cancer_faf99_afr","gnomad_ex_non_cancer_faf99_amr","gnomad_ex_non_cancer_faf99_eas","gnomad_ex_non_cancer_faf99_nfe","gnomad_ex_non_cancer_faf99_sas","gnomad_ex_non_cancer_nhomalt","gnomad_ex_non_cancer_nhomalt_afr","gnomad_ex_non_cancer_nhomalt_afr_female","gnomad_ex_non_cancer_nhomalt_afr_male","gnomad_ex_non_cancer_nhomalt_amr","gnomad_ex_non_cancer_nhomalt_amr_female","gnomad_ex_non_cancer_nhomalt_amr_male","gnomad_ex_non_cancer_nhomalt_asj","gnomad_ex_non_cancer_nhomalt_asj_female","gnomad_ex_non_cancer_nhomalt_asj_male","gnomad_ex_non_cancer_nhomalt_eas","gnomad_ex_non_cancer_nhomalt_eas_female","gnomad_ex_non_cancer_nhomalt_eas_jpn","gnomad_ex_non_cancer_nhomalt_eas_kor","gnomad_ex_non_cancer_nhomalt_eas_male","gnomad_ex_non_cancer_nhomalt_eas_oea","gnomad_ex_non_cancer_nhomalt_female","gnomad_ex_non_cancer_nhomalt_fin","gnomad_ex_non_cancer_nhomalt_fin_female","gnomad_ex_non_cancer_nhomalt_fin_male","gnomad_ex_non_cancer_nhomalt_male","gnomad_ex_non_cancer_nhomalt_nfe","gnomad_ex_non_cancer_nhomalt_nfe_bgr","gnomad_ex_non_cancer_nhomalt_nfe_est","gnomad_ex_non_cancer_nhomalt_nfe_female","gnomad_ex_non_cancer_nhomalt_nfe_male","gnomad_ex_non_cancer_nhomalt_nfe_nwe","gnomad_ex_non_cancer_nhomalt_nfe_onf","gnomad_ex_non_cancer_nhomalt_nfe_seu","gnomad_ex_non_cancer_nhomalt_nfe_swe","gnomad_ex_non_cancer_nhomalt_oth","gnomad_ex_non_cancer_nhomalt_oth_female","gnomad_ex_non_cancer_nhomalt_oth_male","gnomad_ex_non_cancer_nhomalt_popmax","gnomad_ex_non_cancer_nhomalt_raw","gnomad_ex_non_cancer_nhomalt_sas","gnomad_ex_non_cancer_nhomalt_sas_female","gnomad_ex_non_cancer_nhomalt_sas_male","gnomad_ex_non_cancer_popmax","gnomad_ex_non_neuro_AC","gnomad_ex_non_neuro_AC_afr","gnomad_ex_non_neuro_AC_afr_female","gnomad_ex_non_neuro_AC_afr_male","gnomad_ex_non_neuro_AC_amr","gnomad_ex_non_neuro_AC_amr_female","gnomad_ex_non_neuro_AC_amr_male","gnomad_ex_non_neuro_AC_asj","gnomad_ex_non_neuro_AC_asj_female","gnomad_ex_non_neuro_AC_asj_male","gnomad_ex_non_neuro_AC_eas","gnomad_ex_non_neuro_AC_eas_female","gnomad_ex_non_neuro_AC_eas_jpn","gnomad_ex_non_neuro_AC_eas_kor","gnomad_ex_non_neuro_AC_eas_male","gnomad_ex_non_neuro_AC_eas_oea","gnomad_ex_non_neuro_AC_female","gnomad_ex_non_neuro_AC_fin","gnomad_ex_non_neuro_AC_fin_female","gnomad_ex_non_neuro_AC_fin_male","gnomad_ex_non_neuro_AC_male","gnomad_ex_non_neuro_AC_nfe","gnomad_ex_non_neuro_AC_nfe_bgr","gnomad_ex_non_neuro_AC_nfe_est","gnomad_ex_non_neuro_AC_nfe_female","gnomad_ex_non_neuro_AC_nfe_male","gnomad_ex_non_neuro_AC_nfe_nwe","gnomad_ex_non_neuro_AC_nfe_onf","gnomad_ex_non_neuro_AC_nfe_seu","gnomad_ex_non_neuro_AC_nfe_swe","gnomad_ex_non_neuro_AC_oth","gnomad_ex_non_neuro_AC_oth_female","gnomad_ex_non_neuro_AC_oth_male","gnomad_ex_non_neuro_AC_popmax","gnomad_ex_non_neuro_AC_raw","gnomad_ex_non_neuro_AC_sas","gnomad_ex_non_neuro_AC_sas_female","gnomad_ex_non_neuro_AC_sas_male","gnomad_ex_non_neuro_AF","gnomad_ex_non_neuro_AF_afr","gnomad_ex_non_neuro_AF_afr_female","gnomad_ex_non_neuro_AF_afr_male","gnomad_ex_non_neuro_AF_amr","gnomad_ex_non_neuro_AF_amr_female","gnomad_ex_non_neuro_AF_amr_male","gnomad_ex_non_neuro_AF_asj","gnomad_ex_non_neuro_AF_asj_female","gnomad_ex_non_neuro_AF_asj_male","gnomad_ex_non_neuro_AF_eas","gnomad_ex_non_neuro_AF_eas_female","gnomad_ex_non_neuro_AF_eas_jpn","gnomad_ex_non_neuro_AF_eas_kor","gnomad_ex_non_neuro_AF_eas_male","gnomad_ex_non_neuro_AF_eas_oea","gnomad_ex_non_neuro_AF_female","gnomad_ex_non_neuro_AF_fin","gnomad_ex_non_neuro_AF_fin_female","gnomad_ex_non_neuro_AF_fin_male","gnomad_ex_non_neuro_AF_male","gnomad_ex_non_neuro_AF_nfe","gnomad_ex_non_neuro_AF_nfe_bgr","gnomad_ex_non_neuro_AF_nfe_est","gnomad_ex_non_neuro_AF_nfe_female","gnomad_ex_non_neuro_AF_nfe_male","gnomad_ex_non_neuro_AF_nfe_nwe","gnomad_ex_non_neuro_AF_nfe_onf","gnomad_ex_non_neuro_AF_nfe_seu","gnomad_ex_non_neuro_AF_nfe_swe","gnomad_ex_non_neuro_AF_oth","gnomad_ex_non_neuro_AF_oth_female","gnomad_ex_non_neuro_AF_oth_male","gnomad_ex_non_neuro_AF_popmax","gnomad_ex_non_neuro_AF_raw","gnomad_ex_non_neuro_AF_sas","gnomad_ex_non_neuro_AF_sas_female","gnomad_ex_non_neuro_AF_sas_male","gnomad_ex_non_neuro_AN","gnomad_ex_non_neuro_AN_afr","gnomad_ex_non_neuro_AN_afr_female","gnomad_ex_non_neuro_AN_afr_male","gnomad_ex_non_neuro_AN_amr","gnomad_ex_non_neuro_AN_amr_female","gnomad_ex_non_neuro_AN_amr_male","gnomad_ex_non_neuro_AN_asj","gnomad_ex_non_neuro_AN_asj_female","gnomad_ex_non_neuro_AN_asj_male","gnomad_ex_non_neuro_AN_eas","gnomad_ex_non_neuro_AN_eas_female","gnomad_ex_non_neuro_AN_eas_jpn","gnomad_ex_non_neuro_AN_eas_kor","gnomad_ex_non_neuro_AN_eas_male","gnomad_ex_non_neuro_AN_eas_oea","gnomad_ex_non_neuro_AN_female","gnomad_ex_non_neuro_AN_fin","gnomad_ex_non_neuro_AN_fin_female","gnomad_ex_non_neuro_AN_fin_male","gnomad_ex_non_neuro_AN_male","gnomad_ex_non_neuro_AN_nfe","gnomad_ex_non_neuro_AN_nfe_bgr","gnomad_ex_non_neuro_AN_nfe_est","gnomad_ex_non_neuro_AN_nfe_female","gnomad_ex_non_neuro_AN_nfe_male","gnomad_ex_non_neuro_AN_nfe_nwe","gnomad_ex_non_neuro_AN_nfe_onf","gnomad_ex_non_neuro_AN_nfe_seu","gnomad_ex_non_neuro_AN_nfe_swe","gnomad_ex_non_neuro_AN_oth","gnomad_ex_non_neuro_AN_oth_female","gnomad_ex_non_neuro_AN_oth_male","gnomad_ex_non_neuro_AN_popmax","gnomad_ex_non_neuro_AN_raw","gnomad_ex_non_neuro_AN_sas","gnomad_ex_non_neuro_AN_sas_female","gnomad_ex_non_neuro_AN_sas_male","gnomad_ex_non_neuro_faf95","gnomad_ex_non_neuro_faf95_afr","gnomad_ex_non_neuro_faf95_amr","gnomad_ex_non_neuro_faf95_eas","gnomad_ex_non_neuro_faf95_nfe","gnomad_ex_non_neuro_faf95_sas","gnomad_ex_non_neuro_faf99","gnomad_ex_non_neuro_faf99_afr","gnomad_ex_non_neuro_faf99_amr","gnomad_ex_non_neuro_faf99_eas","gnomad_ex_non_neuro_faf99_nfe","gnomad_ex_non_neuro_faf99_sas","gnomad_ex_non_neuro_nhomalt","gnomad_ex_non_neuro_nhomalt_afr","gnomad_ex_non_neuro_nhomalt_afr_female","gnomad_ex_non_neuro_nhomalt_afr_male","gnomad_ex_non_neuro_nhomalt_amr","gnomad_ex_non_neuro_nhomalt_amr_female","gnomad_ex_non_neuro_nhomalt_amr_male","gnomad_ex_non_neuro_nhomalt_asj","gnomad_ex_non_neuro_nhomalt_asj_female","gnomad_ex_non_neuro_nhomalt_asj_male","gnomad_ex_non_neuro_nhomalt_eas","gnomad_ex_non_neuro_nhomalt_eas_female","gnomad_ex_non_neuro_nhomalt_eas_jpn","gnomad_ex_non_neuro_nhomalt_eas_kor","gnomad_ex_non_neuro_nhomalt_eas_male","gnomad_ex_non_neuro_nhomalt_eas_oea","gnomad_ex_non_neuro_nhomalt_female","gnomad_ex_non_neuro_nhomalt_fin","gnomad_ex_non_neuro_nhomalt_fin_female","gnomad_ex_non_neuro_nhomalt_fin_male","gnomad_ex_non_neuro_nhomalt_male","gnomad_ex_non_neuro_nhomalt_nfe","gnomad_ex_non_neuro_nhomalt_nfe_bgr","gnomad_ex_non_neuro_nhomalt_nfe_est","gnomad_ex_non_neuro_nhomalt_nfe_female","gnomad_ex_non_neuro_nhomalt_nfe_male","gnomad_ex_non_neuro_nhomalt_nfe_nwe","gnomad_ex_non_neuro_nhomalt_nfe_onf","gnomad_ex_non_neuro_nhomalt_nfe_seu","gnomad_ex_non_neuro_nhomalt_nfe_swe","gnomad_ex_non_neuro_nhomalt_oth","gnomad_ex_non_neuro_nhomalt_oth_female","gnomad_ex_non_neuro_nhomalt_oth_male","gnomad_ex_non_neuro_nhomalt_popmax","gnomad_ex_non_neuro_nhomalt_raw","gnomad_ex_non_neuro_nhomalt_sas","gnomad_ex_non_neuro_nhomalt_sas_female","gnomad_ex_non_neuro_nhomalt_sas_male","gnomad_ex_non_neuro_popmax","gnomad_ex_non_topmed_AC","gnomad_ex_non_topmed_AC_afr","gnomad_ex_non_topmed_AC_afr_female","gnomad_ex_non_topmed_AC_afr_male","gnomad_ex_non_topmed_AC_amr","gnomad_ex_non_topmed_AC_amr_female","gnomad_ex_non_topmed_AC_amr_male","gnomad_ex_non_topmed_AC_asj","gnomad_ex_non_topmed_AC_asj_female","gnomad_ex_non_topmed_AC_asj_male","gnomad_ex_non_topmed_AC_eas","gnomad_ex_non_topmed_AC_eas_female","gnomad_ex_non_topmed_AC_eas_jpn","gnomad_ex_non_topmed_AC_eas_kor","gnomad_ex_non_topmed_AC_eas_male","gnomad_ex_non_topmed_AC_eas_oea","gnomad_ex_non_topmed_AC_female","gnomad_ex_non_topmed_AC_fin","gnomad_ex_non_topmed_AC_fin_female","gnomad_ex_non_topmed_AC_fin_male","gnomad_ex_non_topmed_AC_male","gnomad_ex_non_topmed_AC_nfe","gnomad_ex_non_topmed_AC_nfe_bgr","gnomad_ex_non_topmed_AC_nfe_est","gnomad_ex_non_topmed_AC_nfe_female","gnomad_ex_non_topmed_AC_nfe_male","gnomad_ex_non_topmed_AC_nfe_nwe","gnomad_ex_non_topmed_AC_nfe_onf","gnomad_ex_non_topmed_AC_nfe_seu","gnomad_ex_non_topmed_AC_nfe_swe","gnomad_ex_non_topmed_AC_oth","gnomad_ex_non_topmed_AC_oth_female","gnomad_ex_non_topmed_AC_oth_male","gnomad_ex_non_topmed_AC_popmax","gnomad_ex_non_topmed_AC_raw","gnomad_ex_non_topmed_AC_sas","gnomad_ex_non_topmed_AC_sas_female","gnomad_ex_non_topmed_AC_sas_male","gnomad_ex_non_topmed_AF","gnomad_ex_non_topmed_AF_afr","gnomad_ex_non_topmed_AF_afr_female","gnomad_ex_non_topmed_AF_afr_male","gnomad_ex_non_topmed_AF_amr","gnomad_ex_non_topmed_AF_amr_female","gnomad_ex_non_topmed_AF_amr_male","gnomad_ex_non_topmed_AF_asj","gnomad_ex_non_topmed_AF_asj_female","gnomad_ex_non_topmed_AF_asj_male","gnomad_ex_non_topmed_AF_eas","gnomad_ex_non_topmed_AF_eas_female","gnomad_ex_non_topmed_AF_eas_jpn","gnomad_ex_non_topmed_AF_eas_kor","gnomad_ex_non_topmed_AF_eas_male","gnomad_ex_non_topmed_AF_eas_oea","gnomad_ex_non_topmed_AF_female","gnomad_ex_non_topmed_AF_fin","gnomad_ex_non_topmed_AF_fin_female","gnomad_ex_non_topmed_AF_fin_male","gnomad_ex_non_topmed_AF_male","gnomad_ex_non_topmed_AF_nfe","gnomad_ex_non_topmed_AF_nfe_bgr","gnomad_ex_non_topmed_AF_nfe_est","gnomad_ex_non_topmed_AF_nfe_female","gnomad_ex_non_topmed_AF_nfe_male","gnomad_ex_non_topmed_AF_nfe_nwe","gnomad_ex_non_topmed_AF_nfe_onf","gnomad_ex_non_topmed_AF_nfe_seu","gnomad_ex_non_topmed_AF_nfe_swe","gnomad_ex_non_topmed_AF_oth","gnomad_ex_non_topmed_AF_oth_female","gnomad_ex_non_topmed_AF_oth_male","gnomad_ex_non_topmed_AF_popmax","gnomad_ex_non_topmed_AF_raw","gnomad_ex_non_topmed_AF_sas","gnomad_ex_non_topmed_AF_sas_female","gnomad_ex_non_topmed_AF_sas_male","gnomad_ex_non_topmed_AN","gnomad_ex_non_topmed_AN_afr","gnomad_ex_non_topmed_AN_afr_female","gnomad_ex_non_topmed_AN_afr_male","gnomad_ex_non_topmed_AN_amr","gnomad_ex_non_topmed_AN_amr_female","gnomad_ex_non_topmed_AN_amr_male","gnomad_ex_non_topmed_AN_asj","gnomad_ex_non_topmed_AN_asj_female","gnomad_ex_non_topmed_AN_asj_male","gnomad_ex_non_topmed_AN_eas","gnomad_ex_non_topmed_AN_eas_female","gnomad_ex_non_topmed_AN_eas_jpn","gnomad_ex_non_topmed_AN_eas_kor","gnomad_ex_non_topmed_AN_eas_male","gnomad_ex_non_topmed_AN_eas_oea","gnomad_ex_non_topmed_AN_female","gnomad_ex_non_topmed_AN_fin","gnomad_ex_non_topmed_AN_fin_female","gnomad_ex_non_topmed_AN_fin_male","gnomad_ex_non_topmed_AN_male","gnomad_ex_non_topmed_AN_nfe","gnomad_ex_non_topmed_AN_nfe_bgr","gnomad_ex_non_topmed_AN_nfe_est","gnomad_ex_non_topmed_AN_nfe_female","gnomad_ex_non_topmed_AN_nfe_male","gnomad_ex_non_topmed_AN_nfe_nwe","gnomad_ex_non_topmed_AN_nfe_onf","gnomad_ex_non_topmed_AN_nfe_seu","gnomad_ex_non_topmed_AN_nfe_swe","gnomad_ex_non_topmed_AN_oth","gnomad_ex_non_topmed_AN_oth_female","gnomad_ex_non_topmed_AN_oth_male","gnomad_ex_non_topmed_AN_popmax","gnomad_ex_non_topmed_AN_raw","gnomad_ex_non_topmed_AN_sas","gnomad_ex_non_topmed_AN_sas_female","gnomad_ex_non_topmed_AN_sas_male","gnomad_ex_non_topmed_faf95","gnomad_ex_non_topmed_faf95_afr","gnomad_ex_non_topmed_faf95_amr","gnomad_ex_non_topmed_faf95_eas","gnomad_ex_non_topmed_faf95_nfe","gnomad_ex_non_topmed_faf95_sas","gnomad_ex_non_topmed_faf99","gnomad_ex_non_topmed_faf99_afr","gnomad_ex_non_topmed_faf99_amr","gnomad_ex_non_topmed_faf99_eas","gnomad_ex_non_topmed_faf99_nfe","gnomad_ex_non_topmed_faf99_sas","gnomad_ex_non_topmed_nhomalt","gnomad_ex_non_topmed_nhomalt_afr","gnomad_ex_non_topmed_nhomalt_afr_female","gnomad_ex_non_topmed_nhomalt_afr_male","gnomad_ex_non_topmed_nhomalt_amr","gnomad_ex_non_topmed_nhomalt_amr_female","gnomad_ex_non_topmed_nhomalt_amr_male","gnomad_ex_non_topmed_nhomalt_asj","gnomad_ex_non_topmed_nhomalt_asj_female","gnomad_ex_non_topmed_nhomalt_asj_male","gnomad_ex_non_topmed_nhomalt_eas","gnomad_ex_non_topmed_nhomalt_eas_female","gnomad_ex_non_topmed_nhomalt_eas_jpn","gnomad_ex_non_topmed_nhomalt_eas_kor","gnomad_ex_non_topmed_nhomalt_eas_male","gnomad_ex_non_topmed_nhomalt_eas_oea","gnomad_ex_non_topmed_nhomalt_female","gnomad_ex_non_topmed_nhomalt_fin","gnomad_ex_non_topmed_nhomalt_fin_female","gnomad_ex_non_topmed_nhomalt_fin_male","gnomad_ex_non_topmed_nhomalt_male","gnomad_ex_non_topmed_nhomalt_nfe","gnomad_ex_non_topmed_nhomalt_nfe_bgr","gnomad_ex_non_topmed_nhomalt_nfe_est","gnomad_ex_non_topmed_nhomalt_nfe_female","gnomad_ex_non_topmed_nhomalt_nfe_male","gnomad_ex_non_topmed_nhomalt_nfe_nwe","gnomad_ex_non_topmed_nhomalt_nfe_onf","gnomad_ex_non_topmed_nhomalt_nfe_seu","gnomad_ex_non_topmed_nhomalt_nfe_swe","gnomad_ex_non_topmed_nhomalt_oth","gnomad_ex_non_topmed_nhomalt_oth_female","gnomad_ex_non_topmed_nhomalt_oth_male","gnomad_ex_non_topmed_nhomalt_popmax","gnomad_ex_non_topmed_nhomalt_raw","gnomad_ex_non_topmed_nhomalt_sas","gnomad_ex_non_topmed_nhomalt_sas_female","gnomad_ex_non_topmed_nhomalt_sas_male","gnomad_ex_non_topmed_popmax","gnomad_ex_nonpar","gnomad_ex_pab_max","gnomad_ex_popmax","gnomad_ex_QD","gnomad_ex_ReadPosRankSum","gnomad_ex_rf_label","gnomad_ex_rf_negative_label","gnomad_ex_rf_positive_label","gnomad_ex_rf_tp_probability","gnomad_ex_rf_train","gnomad_ex_segdup","gnomad_ex_SOR","gnomad_ex_transmitted_singleton","gnomad_ex_variant_type","gnomad_ex_vep","gnomad_ex_VQSLOD","gnomad_ex_VQSR_culprit","gnomad_ex_VQSR_NEGATIVE_TRAIN_SITE","gnomad_ex_VQSR_POSITIVE_TRAIN_SITE","gnomad_ex_was_mixed"]
# fields = ["ab_hist_alt_bin_freq","AC","AC_afr","AC_afr_female","AC_afr_male","AC_amr","AC_amr_female","AC_amr_male","AC_asj","AC_asj_female","AC_asj_male","AC_eas","AC_eas_female","AC_eas_jpn","AC_eas_kor","AC_eas_male","AC_eas_oea","AC_female","AC_fin","AC_fin_female","AC_fin_male","AC_male","AC_nfe","AC_nfe_bgr","AC_nfe_est","AC_nfe_female","AC_nfe_male","AC_nfe_nwe","AC_nfe_onf","AC_nfe_seu","AC_nfe_swe","AC_oth","AC_oth_female","AC_oth_male","AC_popmax","AC_raw","AC_sas","AC_sas_female","AC_sas_male","AF","AF_afr","AF_afr_female","AF_afr_male","AF_amr","AF_amr_female","AF_amr_male","AF_asj","AF_asj_female","AF_asj_male","AF_eas","AF_eas_female","AF_eas_jpn","AF_eas_kor","AF_eas_male","AF_eas_oea","AF_female","AF_fin","AF_fin_female","AF_fin_male","AF_male","AF_nfe","AF_nfe_bgr","AF_nfe_est","AF_nfe_female","AF_nfe_male","AF_nfe_nwe","AF_nfe_onf","AF_nfe_seu","AF_nfe_swe","AF_oth","AF_oth_female","AF_oth_male","AF_popmax","AF_raw","AF_sas","AF_sas_female","AF_sas_male","age_hist_het_bin_freq","age_hist_het_n_larger","age_hist_het_n_smaller","age_hist_hom_bin_freq","age_hist_hom_n_larger","age_hist_hom_n_smaller","allele_type","AN","AN_afr","AN_afr_female","AN_afr_male","AN_amr","AN_amr_female","AN_amr_male","AN_asj","AN_asj_female","AN_asj_male","AN_eas","AN_eas_female","AN_eas_jpn","AN_eas_kor","AN_eas_male","AN_eas_oea","AN_female","AN_fin","AN_fin_female","AN_fin_male","AN_male","AN_nfe","AN_nfe_bgr","AN_nfe_est","AN_nfe_female","AN_nfe_male","AN_nfe_nwe","AN_nfe_onf","AN_nfe_seu","AN_nfe_swe","AN_oth","AN_oth_female","AN_oth_male","AN_popmax","AN_raw","AN_sas","AN_sas_female","AN_sas_male","BaseQRankSum","ClippingRankSum","controls_AC","controls_AC_afr","controls_AC_afr_female","controls_AC_afr_male","controls_AC_amr","controls_AC_amr_female","controls_AC_amr_male","controls_AC_asj","controls_AC_asj_female","controls_AC_asj_male","controls_AC_eas","controls_AC_eas_female","controls_AC_eas_jpn","controls_AC_eas_kor","controls_AC_eas_male","controls_AC_eas_oea","controls_AC_female","controls_AC_fin","controls_AC_fin_female","controls_AC_fin_male","controls_AC_male","controls_AC_nfe","controls_AC_nfe_bgr","controls_AC_nfe_est","controls_AC_nfe_female","controls_AC_nfe_male","controls_AC_nfe_nwe","controls_AC_nfe_onf","controls_AC_nfe_seu","controls_AC_nfe_swe","controls_AC_oth","controls_AC_oth_female","controls_AC_oth_male","controls_AC_popmax","controls_AC_raw","controls_AC_sas","controls_AC_sas_female","controls_AC_sas_male","controls_AF","controls_AF_afr","controls_AF_afr_female","controls_AF_afr_male","controls_AF_amr","controls_AF_amr_female","controls_AF_amr_male","controls_AF_asj","controls_AF_asj_female","controls_AF_asj_male","controls_AF_eas","controls_AF_eas_female","controls_AF_eas_jpn","controls_AF_eas_kor","controls_AF_eas_male","controls_AF_eas_oea","controls_AF_female","controls_AF_fin","controls_AF_fin_female","controls_AF_fin_male","controls_AF_male","controls_AF_nfe","controls_AF_nfe_bgr","controls_AF_nfe_est","controls_AF_nfe_female","controls_AF_nfe_male","controls_AF_nfe_nwe","controls_AF_nfe_onf","controls_AF_nfe_seu","controls_AF_nfe_swe","controls_AF_oth","controls_AF_oth_female","controls_AF_oth_male","controls_AF_popmax","controls_AF_raw","controls_AF_sas","controls_AF_sas_female","controls_AF_sas_male","controls_AN","controls_AN_afr","controls_AN_afr_female","controls_AN_afr_male","controls_AN_amr","controls_AN_amr_female","controls_AN_amr_male","controls_AN_asj","controls_AN_asj_female","controls_AN_asj_male","controls_AN_eas","controls_AN_eas_female","controls_AN_eas_jpn","controls_AN_eas_kor","controls_AN_eas_male","controls_AN_eas_oea","controls_AN_female","controls_AN_fin","controls_AN_fin_female","controls_AN_fin_male","controls_AN_male","controls_AN_nfe","controls_AN_nfe_bgr","controls_AN_nfe_est","controls_AN_nfe_female","controls_AN_nfe_male","controls_AN_nfe_nwe","controls_AN_nfe_onf","controls_AN_nfe_seu","controls_AN_nfe_swe","controls_AN_oth","controls_AN_oth_female","controls_AN_oth_male","controls_AN_popmax","controls_AN_raw","controls_AN_sas","controls_AN_sas_female","controls_AN_sas_male","controls_faf95","controls_faf95_afr","controls_faf95_amr","controls_faf95_eas","controls_faf95_nfe","controls_faf95_sas","controls_faf99","controls_faf99_afr","controls_faf99_amr","controls_faf99_eas","controls_faf99_nfe","controls_faf99_sas","controls_nhomalt","controls_nhomalt_afr","controls_nhomalt_afr_female","controls_nhomalt_afr_male","controls_nhomalt_amr","controls_nhomalt_amr_female","controls_nhomalt_amr_male","controls_nhomalt_asj","controls_nhomalt_asj_female","controls_nhomalt_asj_male","controls_nhomalt_eas","controls_nhomalt_eas_female","controls_nhomalt_eas_jpn","controls_nhomalt_eas_kor","controls_nhomalt_eas_male","controls_nhomalt_eas_oea","controls_nhomalt_female","controls_nhomalt_fin","controls_nhomalt_fin_female","controls_nhomalt_fin_male","controls_nhomalt_male","controls_nhomalt_nfe","controls_nhomalt_nfe_bgr","controls_nhomalt_nfe_est","controls_nhomalt_nfe_female","controls_nhomalt_nfe_male","controls_nhomalt_nfe_nwe","controls_nhomalt_nfe_onf","controls_nhomalt_nfe_seu","controls_nhomalt_nfe_swe","controls_nhomalt_oth","controls_nhomalt_oth_female","controls_nhomalt_oth_male","controls_nhomalt_popmax","controls_nhomalt_raw","controls_nhomalt_sas","controls_nhomalt_sas_female","controls_nhomalt_sas_male","controls_popmax","decoy","DP","dp_hist_all_bin_freq","dp_hist_all_n_larger","dp_hist_alt_bin_freq","dp_hist_alt_n_larger","faf95","faf95_afr","faf95_amr","faf95_eas","faf95_nfe","faf95_sas","faf99","faf99_afr","faf99_amr","faf99_eas","faf99_nfe","faf99_sas","FS","gq_hist_all_bin_freq","gq_hist_alt_bin_freq","has_star","InbreedingCoeff","lcr","MQ","MQRankSum","n_alt_alleles","nhomalt","nhomalt_afr","nhomalt_afr_female","nhomalt_afr_male","nhomalt_amr","nhomalt_amr_female","nhomalt_amr_male","nhomalt_asj","nhomalt_asj_female","nhomalt_asj_male","nhomalt_eas","nhomalt_eas_female","nhomalt_eas_jpn","nhomalt_eas_kor","nhomalt_eas_male","nhomalt_eas_oea","nhomalt_female","nhomalt_fin","nhomalt_fin_female","nhomalt_fin_male","nhomalt_male","nhomalt_nfe","nhomalt_nfe_bgr","nhomalt_nfe_est","nhomalt_nfe_female","nhomalt_nfe_male","nhomalt_nfe_nwe","nhomalt_nfe_onf","nhomalt_nfe_seu","nhomalt_nfe_swe","nhomalt_oth","nhomalt_oth_female","nhomalt_oth_male","nhomalt_popmax","nhomalt_raw","nhomalt_sas","nhomalt_sas_female","nhomalt_sas_male","non_cancer_AC","non_cancer_AC_afr","non_cancer_AC_afr_female","non_cancer_AC_afr_male","non_cancer_AC_amr","non_cancer_AC_amr_female","non_cancer_AC_amr_male","non_cancer_AC_asj","non_cancer_AC_asj_female","non_cancer_AC_asj_male","non_cancer_AC_eas","non_cancer_AC_eas_female","non_cancer_AC_eas_jpn","non_cancer_AC_eas_kor","non_cancer_AC_eas_male","non_cancer_AC_eas_oea","non_cancer_AC_female","non_cancer_AC_fin","non_cancer_AC_fin_female","non_cancer_AC_fin_male","non_cancer_AC_male","non_cancer_AC_nfe","non_cancer_AC_nfe_bgr","non_cancer_AC_nfe_est","non_cancer_AC_nfe_female","non_cancer_AC_nfe_male","non_cancer_AC_nfe_nwe","non_cancer_AC_nfe_onf","non_cancer_AC_nfe_seu","non_cancer_AC_nfe_swe","non_cancer_AC_oth","non_cancer_AC_oth_female","non_cancer_AC_oth_male","non_cancer_AC_popmax","non_cancer_AC_raw","non_cancer_AC_sas","non_cancer_AC_sas_female","non_cancer_AC_sas_male","non_cancer_AF","non_cancer_AF_afr","non_cancer_AF_afr_female","non_cancer_AF_afr_male","non_cancer_AF_amr","non_cancer_AF_amr_female","non_cancer_AF_amr_male","non_cancer_AF_asj","non_cancer_AF_asj_female","non_cancer_AF_asj_male","non_cancer_AF_eas","non_cancer_AF_eas_female","non_cancer_AF_eas_jpn","non_cancer_AF_eas_kor","non_cancer_AF_eas_male","non_cancer_AF_eas_oea","non_cancer_AF_female","non_cancer_AF_fin","non_cancer_AF_fin_female","non_cancer_AF_fin_male","non_cancer_AF_male","non_cancer_AF_nfe","non_cancer_AF_nfe_bgr","non_cancer_AF_nfe_est","non_cancer_AF_nfe_female","non_cancer_AF_nfe_male","non_cancer_AF_nfe_nwe","non_cancer_AF_nfe_onf","non_cancer_AF_nfe_seu","non_cancer_AF_nfe_swe","non_cancer_AF_oth","non_cancer_AF_oth_female","non_cancer_AF_oth_male","non_cancer_AF_popmax","non_cancer_AF_raw","non_cancer_AF_sas","non_cancer_AF_sas_female","non_cancer_AF_sas_male","non_cancer_AN","non_cancer_AN_afr","non_cancer_AN_afr_female","non_cancer_AN_afr_male","non_cancer_AN_amr","non_cancer_AN_amr_female","non_cancer_AN_amr_male","non_cancer_AN_asj","non_cancer_AN_asj_female","non_cancer_AN_asj_male","non_cancer_AN_eas","non_cancer_AN_eas_female","non_cancer_AN_eas_jpn","non_cancer_AN_eas_kor","non_cancer_AN_eas_male","non_cancer_AN_eas_oea","non_cancer_AN_female","non_cancer_AN_fin","non_cancer_AN_fin_female","non_cancer_AN_fin_male","non_cancer_AN_male","non_cancer_AN_nfe","non_cancer_AN_nfe_bgr","non_cancer_AN_nfe_est","non_cancer_AN_nfe_female","non_cancer_AN_nfe_male","non_cancer_AN_nfe_nwe","non_cancer_AN_nfe_onf","non_cancer_AN_nfe_seu","non_cancer_AN_nfe_swe","non_cancer_AN_oth","non_cancer_AN_oth_female","non_cancer_AN_oth_male","non_cancer_AN_popmax","non_cancer_AN_raw","non_cancer_AN_sas","non_cancer_AN_sas_female","non_cancer_AN_sas_male","non_cancer_faf95","non_cancer_faf95_afr","non_cancer_faf95_amr","non_cancer_faf95_eas","non_cancer_faf95_nfe","non_cancer_faf95_sas","non_cancer_faf99","non_cancer_faf99_afr","non_cancer_faf99_amr","non_cancer_faf99_eas","non_cancer_faf99_nfe","non_cancer_faf99_sas","non_cancer_nhomalt","non_cancer_nhomalt_afr","non_cancer_nhomalt_afr_female","non_cancer_nhomalt_afr_male","non_cancer_nhomalt_amr","non_cancer_nhomalt_amr_female","non_cancer_nhomalt_amr_male","non_cancer_nhomalt_asj","non_cancer_nhomalt_asj_female","non_cancer_nhomalt_asj_male","non_cancer_nhomalt_eas","non_cancer_nhomalt_eas_female","non_cancer_nhomalt_eas_jpn","non_cancer_nhomalt_eas_kor","non_cancer_nhomalt_eas_male","non_cancer_nhomalt_eas_oea","non_cancer_nhomalt_female","non_cancer_nhomalt_fin","non_cancer_nhomalt_fin_female","non_cancer_nhomalt_fin_male","non_cancer_nhomalt_male","non_cancer_nhomalt_nfe","non_cancer_nhomalt_nfe_bgr","non_cancer_nhomalt_nfe_est","non_cancer_nhomalt_nfe_female","non_cancer_nhomalt_nfe_male","non_cancer_nhomalt_nfe_nwe","non_cancer_nhomalt_nfe_onf","non_cancer_nhomalt_nfe_seu","non_cancer_nhomalt_nfe_swe","non_cancer_nhomalt_oth","non_cancer_nhomalt_oth_female","non_cancer_nhomalt_oth_male","non_cancer_nhomalt_popmax","non_cancer_nhomalt_raw","non_cancer_nhomalt_sas","non_cancer_nhomalt_sas_female","non_cancer_nhomalt_sas_male","non_cancer_popmax","non_neuro_AC","non_neuro_AC_afr","non_neuro_AC_afr_female","non_neuro_AC_afr_male","non_neuro_AC_amr","non_neuro_AC_amr_female","non_neuro_AC_amr_male","non_neuro_AC_asj","non_neuro_AC_asj_female","non_neuro_AC_asj_male","non_neuro_AC_eas","non_neuro_AC_eas_female","non_neuro_AC_eas_jpn","non_neuro_AC_eas_kor","non_neuro_AC_eas_male","non_neuro_AC_eas_oea","non_neuro_AC_female","non_neuro_AC_fin","non_neuro_AC_fin_female","non_neuro_AC_fin_male","non_neuro_AC_male","non_neuro_AC_nfe","non_neuro_AC_nfe_bgr","non_neuro_AC_nfe_est","non_neuro_AC_nfe_female","non_neuro_AC_nfe_male","non_neuro_AC_nfe_nwe","non_neuro_AC_nfe_onf","non_neuro_AC_nfe_seu","non_neuro_AC_nfe_swe","non_neuro_AC_oth","non_neuro_AC_oth_female","non_neuro_AC_oth_male","non_neuro_AC_popmax","non_neuro_AC_raw","non_neuro_AC_sas","non_neuro_AC_sas_female","non_neuro_AC_sas_male","non_neuro_AF","non_neuro_AF_afr","non_neuro_AF_afr_female","non_neuro_AF_afr_male","non_neuro_AF_amr","non_neuro_AF_amr_female","non_neuro_AF_amr_male","non_neuro_AF_asj","non_neuro_AF_asj_female","non_neuro_AF_asj_male","non_neuro_AF_eas","non_neuro_AF_eas_female","non_neuro_AF_eas_jpn","non_neuro_AF_eas_kor","non_neuro_AF_eas_male","non_neuro_AF_eas_oea","non_neuro_AF_female","non_neuro_AF_fin","non_neuro_AF_fin_female","non_neuro_AF_fin_male","non_neuro_AF_male","non_neuro_AF_nfe","non_neuro_AF_nfe_bgr","non_neuro_AF_nfe_est","non_neuro_AF_nfe_female","non_neuro_AF_nfe_male","non_neuro_AF_nfe_nwe","non_neuro_AF_nfe_onf","non_neuro_AF_nfe_seu","non_neuro_AF_nfe_swe","non_neuro_AF_oth","non_neuro_AF_oth_female","non_neuro_AF_oth_male","non_neuro_AF_popmax","non_neuro_AF_raw","non_neuro_AF_sas","non_neuro_AF_sas_female","non_neuro_AF_sas_male","non_neuro_AN","non_neuro_AN_afr","non_neuro_AN_afr_female","non_neuro_AN_afr_male","non_neuro_AN_amr","non_neuro_AN_amr_female","non_neuro_AN_amr_male","non_neuro_AN_asj","non_neuro_AN_asj_female","non_neuro_AN_asj_male","non_neuro_AN_eas","non_neuro_AN_eas_female","non_neuro_AN_eas_jpn","non_neuro_AN_eas_kor","non_neuro_AN_eas_male","non_neuro_AN_eas_oea","non_neuro_AN_female","non_neuro_AN_fin","non_neuro_AN_fin_female","non_neuro_AN_fin_male","non_neuro_AN_male","non_neuro_AN_nfe","non_neuro_AN_nfe_bgr","non_neuro_AN_nfe_est","non_neuro_AN_nfe_female","non_neuro_AN_nfe_male","non_neuro_AN_nfe_nwe","non_neuro_AN_nfe_onf","non_neuro_AN_nfe_seu","non_neuro_AN_nfe_swe","non_neuro_AN_oth","non_neuro_AN_oth_female","non_neuro_AN_oth_male","non_neuro_AN_popmax","non_neuro_AN_raw","non_neuro_AN_sas","non_neuro_AN_sas_female","non_neuro_AN_sas_male","non_neuro_faf95","non_neuro_faf95_afr","non_neuro_faf95_amr","non_neuro_faf95_eas","non_neuro_faf95_nfe","non_neuro_faf95_sas","non_neuro_faf99","non_neuro_faf99_afr","non_neuro_faf99_amr","non_neuro_faf99_eas","non_neuro_faf99_nfe","non_neuro_faf99_sas","non_neuro_nhomalt","non_neuro_nhomalt_afr","non_neuro_nhomalt_afr_female","non_neuro_nhomalt_afr_male","non_neuro_nhomalt_amr","non_neuro_nhomalt_amr_female","non_neuro_nhomalt_amr_male","non_neuro_nhomalt_asj","non_neuro_nhomalt_asj_female","non_neuro_nhomalt_asj_male","non_neuro_nhomalt_eas","non_neuro_nhomalt_eas_female","non_neuro_nhomalt_eas_jpn","non_neuro_nhomalt_eas_kor","non_neuro_nhomalt_eas_male","non_neuro_nhomalt_eas_oea","non_neuro_nhomalt_female","non_neuro_nhomalt_fin","non_neuro_nhomalt_fin_female","non_neuro_nhomalt_fin_male","non_neuro_nhomalt_male","non_neuro_nhomalt_nfe","non_neuro_nhomalt_nfe_bgr","non_neuro_nhomalt_nfe_est","non_neuro_nhomalt_nfe_female","non_neuro_nhomalt_nfe_male","non_neuro_nhomalt_nfe_nwe","non_neuro_nhomalt_nfe_onf","non_neuro_nhomalt_nfe_seu","non_neuro_nhomalt_nfe_swe","non_neuro_nhomalt_oth","non_neuro_nhomalt_oth_female","non_neuro_nhomalt_oth_male","non_neuro_nhomalt_popmax","non_neuro_nhomalt_raw","non_neuro_nhomalt_sas","non_neuro_nhomalt_sas_female","non_neuro_nhomalt_sas_male","non_neuro_popmax","non_topmed_AC","non_topmed_AC_afr","non_topmed_AC_afr_female","non_topmed_AC_afr_male","non_topmed_AC_amr","non_topmed_AC_amr_female","non_topmed_AC_amr_male","non_topmed_AC_asj","non_topmed_AC_asj_female","non_topmed_AC_asj_male","non_topmed_AC_eas","non_topmed_AC_eas_female","non_topmed_AC_eas_jpn","non_topmed_AC_eas_kor","non_topmed_AC_eas_male","non_topmed_AC_eas_oea","non_topmed_AC_female","non_topmed_AC_fin","non_topmed_AC_fin_female","non_topmed_AC_fin_male","non_topmed_AC_male","non_topmed_AC_nfe","non_topmed_AC_nfe_bgr","non_topmed_AC_nfe_est","non_topmed_AC_nfe_female","non_topmed_AC_nfe_male","non_topmed_AC_nfe_nwe","non_topmed_AC_nfe_onf","non_topmed_AC_nfe_seu","non_topmed_AC_nfe_swe","non_topmed_AC_oth","non_topmed_AC_oth_female","non_topmed_AC_oth_male","non_topmed_AC_popmax","non_topmed_AC_raw","non_topmed_AC_sas","non_topmed_AC_sas_female","non_topmed_AC_sas_male","non_topmed_AF","non_topmed_AF_afr","non_topmed_AF_afr_female","non_topmed_AF_afr_male","non_topmed_AF_amr","non_topmed_AF_amr_female","non_topmed_AF_amr_male","non_topmed_AF_asj","non_topmed_AF_asj_female","non_topmed_AF_asj_male","non_topmed_AF_eas","non_topmed_AF_eas_female","non_topmed_AF_eas_jpn","non_topmed_AF_eas_kor","non_topmed_AF_eas_male","non_topmed_AF_eas_oea","non_topmed_AF_female","non_topmed_AF_fin","non_topmed_AF_fin_female","non_topmed_AF_fin_male","non_topmed_AF_male","non_topmed_AF_nfe","non_topmed_AF_nfe_bgr","non_topmed_AF_nfe_est","non_topmed_AF_nfe_female","non_topmed_AF_nfe_male","non_topmed_AF_nfe_nwe","non_topmed_AF_nfe_onf","non_topmed_AF_nfe_seu","non_topmed_AF_nfe_swe","non_topmed_AF_oth","non_topmed_AF_oth_female","non_topmed_AF_oth_male","non_topmed_AF_popmax","non_topmed_AF_raw","non_topmed_AF_sas","non_topmed_AF_sas_female","non_topmed_AF_sas_male","non_topmed_AN","non_topmed_AN_afr","non_topmed_AN_afr_female","non_topmed_AN_afr_male","non_topmed_AN_amr","non_topmed_AN_amr_female","non_topmed_AN_amr_male","non_topmed_AN_asj","non_topmed_AN_asj_female","non_topmed_AN_asj_male","non_topmed_AN_eas","non_topmed_AN_eas_female","non_topmed_AN_eas_jpn","non_topmed_AN_eas_kor","non_topmed_AN_eas_male","non_topmed_AN_eas_oea","non_topmed_AN_female","non_topmed_AN_fin","non_topmed_AN_fin_female","non_topmed_AN_fin_male","non_topmed_AN_male","non_topmed_AN_nfe","non_topmed_AN_nfe_bgr","non_topmed_AN_nfe_est","non_topmed_AN_nfe_female","non_topmed_AN_nfe_male","non_topmed_AN_nfe_nwe","non_topmed_AN_nfe_onf","non_topmed_AN_nfe_seu","non_topmed_AN_nfe_swe","non_topmed_AN_oth","non_topmed_AN_oth_female","non_topmed_AN_oth_male","non_topmed_AN_popmax","non_topmed_AN_raw","non_topmed_AN_sas","non_topmed_AN_sas_female","non_topmed_AN_sas_male","non_topmed_faf95","non_topmed_faf95_afr","non_topmed_faf95_amr","non_topmed_faf95_eas","non_topmed_faf95_nfe","non_topmed_faf95_sas","non_topmed_faf99","non_topmed_faf99_afr","non_topmed_faf99_amr","non_topmed_faf99_eas","non_topmed_faf99_nfe","non_topmed_faf99_sas","non_topmed_nhomalt","non_topmed_nhomalt_afr","non_topmed_nhomalt_afr_female","non_topmed_nhomalt_afr_male","non_topmed_nhomalt_amr","non_topmed_nhomalt_amr_female","non_topmed_nhomalt_amr_male","non_topmed_nhomalt_asj","non_topmed_nhomalt_asj_female","non_topmed_nhomalt_asj_male","non_topmed_nhomalt_eas","non_topmed_nhomalt_eas_female","non_topmed_nhomalt_eas_jpn","non_topmed_nhomalt_eas_kor","non_topmed_nhomalt_eas_male","non_topmed_nhomalt_eas_oea","non_topmed_nhomalt_female","non_topmed_nhomalt_fin","non_topmed_nhomalt_fin_female","non_topmed_nhomalt_fin_male","non_topmed_nhomalt_male","non_topmed_nhomalt_nfe","non_topmed_nhomalt_nfe_bgr","non_topmed_nhomalt_nfe_est","non_topmed_nhomalt_nfe_female","non_topmed_nhomalt_nfe_male","non_topmed_nhomalt_nfe_nwe","non_topmed_nhomalt_nfe_onf","non_topmed_nhomalt_nfe_seu","non_topmed_nhomalt_nfe_swe","non_topmed_nhomalt_oth","non_topmed_nhomalt_oth_female","non_topmed_nhomalt_oth_male","non_topmed_nhomalt_popmax","non_topmed_nhomalt_raw","non_topmed_nhomalt_sas","non_topmed_nhomalt_sas_female","non_topmed_nhomalt_sas_male","non_topmed_popmax","nonpar","pab_max","popmax","QD","ReadPosRankSum","rf_label","rf_negative_label","rf_positive_label","rf_tp_probability","rf_train","segdup","SOR","transmitted_singleton","variant_type","vep","VQSLOD","VQSR_culprit","VQSR_NEGATIVE_TRAIN_SITE","VQSR_POSITIVE_TRAIN_SITE","was_mixed"]
# ops=["first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first"]


# [[annotation]]
# file="{}/gnomad/gnomad.genomes.r2.1.sites.vcf.gz"
# names = ["gnomad_gen_ab_hist_alt_bin_freq","gnomad_gen_AC","gnomad_gen_AC_afr","gnomad_gen_AC_afr_female","gnomad_gen_AC_afr_male","gnomad_gen_AC_amr","gnomad_gen_AC_amr_female","gnomad_gen_AC_amr_male","gnomad_gen_AC_asj","gnomad_gen_AC_asj_female","gnomad_gen_AC_asj_male","gnomad_gen_AC_eas","gnomad_gen_AC_eas_female","gnomad_gen_AC_eas_male","gnomad_gen_AC_female","gnomad_gen_AC_fin","gnomad_gen_AC_fin_female","gnomad_gen_AC_fin_male","gnomad_gen_AC_male","gnomad_gen_AC_nfe","gnomad_gen_AC_nfe_est","gnomad_gen_AC_nfe_female","gnomad_gen_AC_nfe_male","gnomad_gen_AC_nfe_nwe","gnomad_gen_AC_nfe_onf","gnomad_gen_AC_nfe_seu","gnomad_gen_AC_oth","gnomad_gen_AC_oth_female","gnomad_gen_AC_oth_male","gnomad_gen_AC_popmax","gnomad_gen_AC_raw","gnomad_gen_AF","gnomad_gen_AF_afr","gnomad_gen_AF_afr_female","gnomad_gen_AF_afr_male","gnomad_gen_AF_amr","gnomad_gen_AF_amr_female","gnomad_gen_AF_amr_male","gnomad_gen_AF_asj","gnomad_gen_AF_asj_female","gnomad_gen_AF_asj_male","gnomad_gen_AF_eas","gnomad_gen_AF_eas_female","gnomad_gen_AF_eas_male","gnomad_gen_AF_female","gnomad_gen_AF_fin","gnomad_gen_AF_fin_female","gnomad_gen_AF_fin_male","gnomad_gen_AF_male","gnomad_gen_AF_nfe","gnomad_gen_AF_nfe_est","gnomad_gen_AF_nfe_female","gnomad_gen_AF_nfe_male","gnomad_gen_AF_nfe_nwe","gnomad_gen_AF_nfe_onf","gnomad_gen_AF_nfe_seu","gnomad_gen_AF_oth","gnomad_gen_AF_oth_female","gnomad_gen_AF_oth_male","gnomad_gen_AF_popmax","gnomad_gen_AF_raw","gnomad_gen_age_hist_het_bin_freq","gnomad_gen_age_hist_het_n_larger","gnomad_gen_age_hist_het_n_smaller","gnomad_gen_age_hist_hom_bin_freq","gnomad_gen_age_hist_hom_n_larger","gnomad_gen_age_hist_hom_n_smaller","gnomad_gen_allele_type","gnomad_gen_AN","gnomad_gen_AN_afr","gnomad_gen_AN_afr_female","gnomad_gen_AN_afr_male","gnomad_gen_AN_amr","gnomad_gen_AN_amr_female","gnomad_gen_AN_amr_male","gnomad_gen_AN_asj","gnomad_gen_AN_asj_female","gnomad_gen_AN_asj_male","gnomad_gen_AN_eas","gnomad_gen_AN_eas_female","gnomad_gen_AN_eas_male","gnomad_gen_AN_female","gnomad_gen_AN_fin","gnomad_gen_AN_fin_female","gnomad_gen_AN_fin_male","gnomad_gen_AN_male","gnomad_gen_AN_nfe","gnomad_gen_AN_nfe_est","gnomad_gen_AN_nfe_female","gnomad_gen_AN_nfe_male","gnomad_gen_AN_nfe_nwe","gnomad_gen_AN_nfe_onf","gnomad_gen_AN_nfe_seu","gnomad_gen_AN_oth","gnomad_gen_AN_oth_female","gnomad_gen_AN_oth_male","gnomad_gen_AN_popmax","gnomad_gen_AN_raw","gnomad_gen_BaseQRankSum","gnomad_gen_ClippingRankSum","gnomad_gen_controls_AC","gnomad_gen_controls_AC_afr","gnomad_gen_controls_AC_afr_female","gnomad_gen_controls_AC_afr_male","gnomad_gen_controls_AC_amr","gnomad_gen_controls_AC_amr_female","gnomad_gen_controls_AC_amr_male","gnomad_gen_controls_AC_asj","gnomad_gen_controls_AC_asj_female","gnomad_gen_controls_AC_asj_male","gnomad_gen_controls_AC_eas","gnomad_gen_controls_AC_eas_female","gnomad_gen_controls_AC_eas_male","gnomad_gen_controls_AC_female","gnomad_gen_controls_AC_fin","gnomad_gen_controls_AC_fin_female","gnomad_gen_controls_AC_fin_male","gnomad_gen_controls_AC_male","gnomad_gen_controls_AC_nfe","gnomad_gen_controls_AC_nfe_est","gnomad_gen_controls_AC_nfe_female","gnomad_gen_controls_AC_nfe_male","gnomad_gen_controls_AC_nfe_nwe","gnomad_gen_controls_AC_nfe_onf","gnomad_gen_controls_AC_nfe_seu","gnomad_gen_controls_AC_oth","gnomad_gen_controls_AC_oth_female","gnomad_gen_controls_AC_oth_male","gnomad_gen_controls_AC_popmax","gnomad_gen_controls_AC_raw","gnomad_gen_controls_AF","gnomad_gen_controls_AF_afr","gnomad_gen_controls_AF_afr_female","gnomad_gen_controls_AF_afr_male","gnomad_gen_controls_AF_amr","gnomad_gen_controls_AF_amr_female","gnomad_gen_controls_AF_amr_male","gnomad_gen_controls_AF_asj","gnomad_gen_controls_AF_asj_female","gnomad_gen_controls_AF_asj_male","gnomad_gen_controls_AF_eas","gnomad_gen_controls_AF_eas_female","gnomad_gen_controls_AF_eas_male","gnomad_gen_controls_AF_female","gnomad_gen_controls_AF_fin","gnomad_gen_controls_AF_fin_female","gnomad_gen_controls_AF_fin_male","gnomad_gen_controls_AF_male","gnomad_gen_controls_AF_nfe","gnomad_gen_controls_AF_nfe_est","gnomad_gen_controls_AF_nfe_female","gnomad_gen_controls_AF_nfe_male","gnomad_gen_controls_AF_nfe_nwe","gnomad_gen_controls_AF_nfe_onf","gnomad_gen_controls_AF_nfe_seu","gnomad_gen_controls_AF_oth","gnomad_gen_controls_AF_oth_female","gnomad_gen_controls_AF_oth_male","gnomad_gen_controls_AF_popmax","gnomad_gen_controls_AF_raw","gnomad_gen_controls_AN","gnomad_gen_controls_AN_afr","gnomad_gen_controls_AN_afr_female","gnomad_gen_controls_AN_afr_male","gnomad_gen_controls_AN_amr","gnomad_gen_controls_AN_amr_female","gnomad_gen_controls_AN_amr_male","gnomad_gen_controls_AN_asj","gnomad_gen_controls_AN_asj_female","gnomad_gen_controls_AN_asj_male","gnomad_gen_controls_AN_eas","gnomad_gen_controls_AN_eas_female","gnomad_gen_controls_AN_eas_male","gnomad_gen_controls_AN_female","gnomad_gen_controls_AN_fin","gnomad_gen_controls_AN_fin_female","gnomad_gen_controls_AN_fin_male","gnomad_gen_controls_AN_male","gnomad_gen_controls_AN_nfe","gnomad_gen_controls_AN_nfe_est","gnomad_gen_controls_AN_nfe_female","gnomad_gen_controls_AN_nfe_male","gnomad_gen_controls_AN_nfe_nwe","gnomad_gen_controls_AN_nfe_onf","gnomad_gen_controls_AN_nfe_seu","gnomad_gen_controls_AN_oth","gnomad_gen_controls_AN_oth_female","gnomad_gen_controls_AN_oth_male","gnomad_gen_controls_AN_popmax","gnomad_gen_controls_AN_raw","gnomad_gen_controls_faf95","gnomad_gen_controls_faf95_afr","gnomad_gen_controls_faf95_amr","gnomad_gen_controls_faf95_eas","gnomad_gen_controls_faf95_nfe","gnomad_gen_controls_faf99","gnomad_gen_controls_faf99_afr","gnomad_gen_controls_faf99_amr","gnomad_gen_controls_faf99_eas","gnomad_gen_controls_faf99_nfe","gnomad_gen_controls_nhomalt","gnomad_gen_controls_nhomalt_afr","gnomad_gen_controls_nhomalt_afr_female","gnomad_gen_controls_nhomalt_afr_male","gnomad_gen_controls_nhomalt_amr","gnomad_gen_controls_nhomalt_amr_female","gnomad_gen_controls_nhomalt_amr_male","gnomad_gen_controls_nhomalt_asj","gnomad_gen_controls_nhomalt_asj_female","gnomad_gen_controls_nhomalt_asj_male","gnomad_gen_controls_nhomalt_eas","gnomad_gen_controls_nhomalt_eas_female","gnomad_gen_controls_nhomalt_eas_male","gnomad_gen_controls_nhomalt_female","gnomad_gen_controls_nhomalt_fin","gnomad_gen_controls_nhomalt_fin_female","gnomad_gen_controls_nhomalt_fin_male","gnomad_gen_controls_nhomalt_male","gnomad_gen_controls_nhomalt_nfe","gnomad_gen_controls_nhomalt_nfe_est","gnomad_gen_controls_nhomalt_nfe_female","gnomad_gen_controls_nhomalt_nfe_male","gnomad_gen_controls_nhomalt_nfe_nwe","gnomad_gen_controls_nhomalt_nfe_onf","gnomad_gen_controls_nhomalt_nfe_seu","gnomad_gen_controls_nhomalt_oth","gnomad_gen_controls_nhomalt_oth_female","gnomad_gen_controls_nhomalt_oth_male","gnomad_gen_controls_nhomalt_popmax","gnomad_gen_controls_nhomalt_raw","gnomad_gen_controls_popmax","gnomad_gen_decoy","gnomad_gen_DP","gnomad_gen_dp_hist_all_bin_freq","gnomad_gen_dp_hist_all_n_larger","gnomad_gen_dp_hist_alt_bin_freq","gnomad_gen_dp_hist_alt_n_larger","gnomad_gen_faf95","gnomad_gen_faf95_afr","gnomad_gen_faf95_amr","gnomad_gen_faf95_eas","gnomad_gen_faf95_nfe","gnomad_gen_faf99","gnomad_gen_faf99_afr","gnomad_gen_faf99_amr","gnomad_gen_faf99_eas","gnomad_gen_faf99_nfe","gnomad_gen_FS","gnomad_gen_gq_hist_all_bin_freq","gnomad_gen_gq_hist_alt_bin_freq","gnomad_gen_has_star","gnomad_gen_InbreedingCoeff","gnomad_gen_lcr","gnomad_gen_MQ","gnomad_gen_MQRankSum","gnomad_gen_n_alt_alleles","gnomad_gen_nhomalt","gnomad_gen_nhomalt_afr","gnomad_gen_nhomalt_afr_female","gnomad_gen_nhomalt_afr_male","gnomad_gen_nhomalt_amr","gnomad_gen_nhomalt_amr_female","gnomad_gen_nhomalt_amr_male","gnomad_gen_nhomalt_asj","gnomad_gen_nhomalt_asj_female","gnomad_gen_nhomalt_asj_male","gnomad_gen_nhomalt_eas","gnomad_gen_nhomalt_eas_female","gnomad_gen_nhomalt_eas_male","gnomad_gen_nhomalt_female","gnomad_gen_nhomalt_fin","gnomad_gen_nhomalt_fin_female","gnomad_gen_nhomalt_fin_male","gnomad_gen_nhomalt_male","gnomad_gen_nhomalt_nfe","gnomad_gen_nhomalt_nfe_est","gnomad_gen_nhomalt_nfe_female","gnomad_gen_nhomalt_nfe_male","gnomad_gen_nhomalt_nfe_nwe","gnomad_gen_nhomalt_nfe_onf","gnomad_gen_nhomalt_nfe_seu","gnomad_gen_nhomalt_oth","gnomad_gen_nhomalt_oth_female","gnomad_gen_nhomalt_oth_male","gnomad_gen_nhomalt_popmax","gnomad_gen_nhomalt_raw","gnomad_gen_non_neuro_AC","gnomad_gen_non_neuro_AC_afr","gnomad_gen_non_neuro_AC_afr_female","gnomad_gen_non_neuro_AC_afr_male","gnomad_gen_non_neuro_AC_amr","gnomad_gen_non_neuro_AC_amr_female","gnomad_gen_non_neuro_AC_amr_male","gnomad_gen_non_neuro_AC_asj","gnomad_gen_non_neuro_AC_asj_female","gnomad_gen_non_neuro_AC_asj_male","gnomad_gen_non_neuro_AC_eas","gnomad_gen_non_neuro_AC_eas_female","gnomad_gen_non_neuro_AC_eas_male","gnomad_gen_non_neuro_AC_female","gnomad_gen_non_neuro_AC_fin","gnomad_gen_non_neuro_AC_fin_female","gnomad_gen_non_neuro_AC_fin_male","gnomad_gen_non_neuro_AC_male","gnomad_gen_non_neuro_AC_nfe","gnomad_gen_non_neuro_AC_nfe_est","gnomad_gen_non_neuro_AC_nfe_female","gnomad_gen_non_neuro_AC_nfe_male","gnomad_gen_non_neuro_AC_nfe_nwe","gnomad_gen_non_neuro_AC_nfe_onf","gnomad_gen_non_neuro_AC_nfe_seu","gnomad_gen_non_neuro_AC_oth","gnomad_gen_non_neuro_AC_oth_female","gnomad_gen_non_neuro_AC_oth_male","gnomad_gen_non_neuro_AC_popmax","gnomad_gen_non_neuro_AC_raw","gnomad_gen_non_neuro_AF","gnomad_gen_non_neuro_AF_afr","gnomad_gen_non_neuro_AF_afr_female","gnomad_gen_non_neuro_AF_afr_male","gnomad_gen_non_neuro_AF_amr","gnomad_gen_non_neuro_AF_amr_female","gnomad_gen_non_neuro_AF_amr_male","gnomad_gen_non_neuro_AF_asj","gnomad_gen_non_neuro_AF_asj_female","gnomad_gen_non_neuro_AF_asj_male","gnomad_gen_non_neuro_AF_eas","gnomad_gen_non_neuro_AF_eas_female","gnomad_gen_non_neuro_AF_eas_male","gnomad_gen_non_neuro_AF_female","gnomad_gen_non_neuro_AF_fin","gnomad_gen_non_neuro_AF_fin_female","gnomad_gen_non_neuro_AF_fin_male","gnomad_gen_non_neuro_AF_male","gnomad_gen_non_neuro_AF_nfe","gnomad_gen_non_neuro_AF_nfe_est","gnomad_gen_non_neuro_AF_nfe_female","gnomad_gen_non_neuro_AF_nfe_male","gnomad_gen_non_neuro_AF_nfe_nwe","gnomad_gen_non_neuro_AF_nfe_onf","gnomad_gen_non_neuro_AF_nfe_seu","gnomad_gen_non_neuro_AF_oth","gnomad_gen_non_neuro_AF_oth_female","gnomad_gen_non_neuro_AF_oth_male","gnomad_gen_non_neuro_AF_popmax","gnomad_gen_non_neuro_AF_raw","gnomad_gen_non_neuro_AN","gnomad_gen_non_neuro_AN_afr","gnomad_gen_non_neuro_AN_afr_female","gnomad_gen_non_neuro_AN_afr_male","gnomad_gen_non_neuro_AN_amr","gnomad_gen_non_neuro_AN_amr_female","gnomad_gen_non_neuro_AN_amr_male","gnomad_gen_non_neuro_AN_asj","gnomad_gen_non_neuro_AN_asj_female","gnomad_gen_non_neuro_AN_asj_male","gnomad_gen_non_neuro_AN_eas","gnomad_gen_non_neuro_AN_eas_female","gnomad_gen_non_neuro_AN_eas_male","gnomad_gen_non_neuro_AN_female","gnomad_gen_non_neuro_AN_fin","gnomad_gen_non_neuro_AN_fin_female","gnomad_gen_non_neuro_AN_fin_male","gnomad_gen_non_neuro_AN_male","gnomad_gen_non_neuro_AN_nfe","gnomad_gen_non_neuro_AN_nfe_est","gnomad_gen_non_neuro_AN_nfe_female","gnomad_gen_non_neuro_AN_nfe_male","gnomad_gen_non_neuro_AN_nfe_nwe","gnomad_gen_non_neuro_AN_nfe_onf","gnomad_gen_non_neuro_AN_nfe_seu","gnomad_gen_non_neuro_AN_oth","gnomad_gen_non_neuro_AN_oth_female","gnomad_gen_non_neuro_AN_oth_male","gnomad_gen_non_neuro_AN_popmax","gnomad_gen_non_neuro_AN_raw","gnomad_gen_non_neuro_faf95","gnomad_gen_non_neuro_faf95_afr","gnomad_gen_non_neuro_faf95_amr","gnomad_gen_non_neuro_faf95_eas","gnomad_gen_non_neuro_faf95_nfe","gnomad_gen_non_neuro_faf99","gnomad_gen_non_neuro_faf99_afr","gnomad_gen_non_neuro_faf99_amr","gnomad_gen_non_neuro_faf99_eas","gnomad_gen_non_neuro_faf99_nfe","gnomad_gen_non_neuro_nhomalt","gnomad_gen_non_neuro_nhomalt_afr","gnomad_gen_non_neuro_nhomalt_afr_female","gnomad_gen_non_neuro_nhomalt_afr_male","gnomad_gen_non_neuro_nhomalt_amr","gnomad_gen_non_neuro_nhomalt_amr_female","gnomad_gen_non_neuro_nhomalt_amr_male","gnomad_gen_non_neuro_nhomalt_asj","gnomad_gen_non_neuro_nhomalt_asj_female","gnomad_gen_non_neuro_nhomalt_asj_male","gnomad_gen_non_neuro_nhomalt_eas","gnomad_gen_non_neuro_nhomalt_eas_female","gnomad_gen_non_neuro_nhomalt_eas_male","gnomad_gen_non_neuro_nhomalt_female","gnomad_gen_non_neuro_nhomalt_fin","gnomad_gen_non_neuro_nhomalt_fin_female","gnomad_gen_non_neuro_nhomalt_fin_male","gnomad_gen_non_neuro_nhomalt_male","gnomad_gen_non_neuro_nhomalt_nfe","gnomad_gen_non_neuro_nhomalt_nfe_est","gnomad_gen_non_neuro_nhomalt_nfe_female","gnomad_gen_non_neuro_nhomalt_nfe_male","gnomad_gen_non_neuro_nhomalt_nfe_nwe","gnomad_gen_non_neuro_nhomalt_nfe_onf","gnomad_gen_non_neuro_nhomalt_nfe_seu","gnomad_gen_non_neuro_nhomalt_oth","gnomad_gen_non_neuro_nhomalt_oth_female","gnomad_gen_non_neuro_nhomalt_oth_male","gnomad_gen_non_neuro_nhomalt_popmax","gnomad_gen_non_neuro_nhomalt_raw","gnomad_gen_non_neuro_popmax","gnomad_gen_non_topmed_AC","gnomad_gen_non_topmed_AC_afr","gnomad_gen_non_topmed_AC_afr_female","gnomad_gen_non_topmed_AC_afr_male","gnomad_gen_non_topmed_AC_amr","gnomad_gen_non_topmed_AC_amr_female","gnomad_gen_non_topmed_AC_amr_male","gnomad_gen_non_topmed_AC_asj","gnomad_gen_non_topmed_AC_asj_female","gnomad_gen_non_topmed_AC_asj_male","gnomad_gen_non_topmed_AC_eas","gnomad_gen_non_topmed_AC_eas_female","gnomad_gen_non_topmed_AC_eas_male","gnomad_gen_non_topmed_AC_female","gnomad_gen_non_topmed_AC_fin","gnomad_gen_non_topmed_AC_fin_female","gnomad_gen_non_topmed_AC_fin_male","gnomad_gen_non_topmed_AC_male","gnomad_gen_non_topmed_AC_nfe","gnomad_gen_non_topmed_AC_nfe_est","gnomad_gen_non_topmed_AC_nfe_female","gnomad_gen_non_topmed_AC_nfe_male","gnomad_gen_non_topmed_AC_nfe_nwe","gnomad_gen_non_topmed_AC_nfe_onf","gnomad_gen_non_topmed_AC_nfe_seu","gnomad_gen_non_topmed_AC_oth","gnomad_gen_non_topmed_AC_oth_female","gnomad_gen_non_topmed_AC_oth_male","gnomad_gen_non_topmed_AC_popmax","gnomad_gen_non_topmed_AC_raw","gnomad_gen_non_topmed_AF","gnomad_gen_non_topmed_AF_afr","gnomad_gen_non_topmed_AF_afr_female","gnomad_gen_non_topmed_AF_afr_male","gnomad_gen_non_topmed_AF_amr","gnomad_gen_non_topmed_AF_amr_female","gnomad_gen_non_topmed_AF_amr_male","gnomad_gen_non_topmed_AF_asj","gnomad_gen_non_topmed_AF_asj_female","gnomad_gen_non_topmed_AF_asj_male","gnomad_gen_non_topmed_AF_eas","gnomad_gen_non_topmed_AF_eas_female","gnomad_gen_non_topmed_AF_eas_male","gnomad_gen_non_topmed_AF_female","gnomad_gen_non_topmed_AF_fin","gnomad_gen_non_topmed_AF_fin_female","gnomad_gen_non_topmed_AF_fin_male","gnomad_gen_non_topmed_AF_male","gnomad_gen_non_topmed_AF_nfe","gnomad_gen_non_topmed_AF_nfe_est","gnomad_gen_non_topmed_AF_nfe_female","gnomad_gen_non_topmed_AF_nfe_male","gnomad_gen_non_topmed_AF_nfe_nwe","gnomad_gen_non_topmed_AF_nfe_onf","gnomad_gen_non_topmed_AF_nfe_seu","gnomad_gen_non_topmed_AF_oth","gnomad_gen_non_topmed_AF_oth_female","gnomad_gen_non_topmed_AF_oth_male","gnomad_gen_non_topmed_AF_popmax","gnomad_gen_non_topmed_AF_raw","gnomad_gen_non_topmed_AN","gnomad_gen_non_topmed_AN_afr","gnomad_gen_non_topmed_AN_afr_female","gnomad_gen_non_topmed_AN_afr_male","gnomad_gen_non_topmed_AN_amr","gnomad_gen_non_topmed_AN_amr_female","gnomad_gen_non_topmed_AN_amr_male","gnomad_gen_non_topmed_AN_asj","gnomad_gen_non_topmed_AN_asj_female","gnomad_gen_non_topmed_AN_asj_male","gnomad_gen_non_topmed_AN_eas","gnomad_gen_non_topmed_AN_eas_female","gnomad_gen_non_topmed_AN_eas_male","gnomad_gen_non_topmed_AN_female","gnomad_gen_non_topmed_AN_fin","gnomad_gen_non_topmed_AN_fin_female","gnomad_gen_non_topmed_AN_fin_male","gnomad_gen_non_topmed_AN_male","gnomad_gen_non_topmed_AN_nfe","gnomad_gen_non_topmed_AN_nfe_est","gnomad_gen_non_topmed_AN_nfe_female","gnomad_gen_non_topmed_AN_nfe_male","gnomad_gen_non_topmed_AN_nfe_nwe","gnomad_gen_non_topmed_AN_nfe_onf","gnomad_gen_non_topmed_AN_nfe_seu","gnomad_gen_non_topmed_AN_oth","gnomad_gen_non_topmed_AN_oth_female","gnomad_gen_non_topmed_AN_oth_male","gnomad_gen_non_topmed_AN_popmax","gnomad_gen_non_topmed_AN_raw","gnomad_gen_non_topmed_faf95","gnomad_gen_non_topmed_faf95_afr","gnomad_gen_non_topmed_faf95_amr","gnomad_gen_non_topmed_faf95_eas","gnomad_gen_non_topmed_faf95_nfe","gnomad_gen_non_topmed_faf99","gnomad_gen_non_topmed_faf99_afr","gnomad_gen_non_topmed_faf99_amr","gnomad_gen_non_topmed_faf99_eas","gnomad_gen_non_topmed_faf99_nfe","gnomad_gen_non_topmed_nhomalt","gnomad_gen_non_topmed_nhomalt_afr","gnomad_gen_non_topmed_nhomalt_afr_female","gnomad_gen_non_topmed_nhomalt_afr_male","gnomad_gen_non_topmed_nhomalt_amr","gnomad_gen_non_topmed_nhomalt_amr_female","gnomad_gen_non_topmed_nhomalt_amr_male","gnomad_gen_non_topmed_nhomalt_asj","gnomad_gen_non_topmed_nhomalt_asj_female","gnomad_gen_non_topmed_nhomalt_asj_male","gnomad_gen_non_topmed_nhomalt_eas","gnomad_gen_non_topmed_nhomalt_eas_female","gnomad_gen_non_topmed_nhomalt_eas_male","gnomad_gen_non_topmed_nhomalt_female","gnomad_gen_non_topmed_nhomalt_fin","gnomad_gen_non_topmed_nhomalt_fin_female","gnomad_gen_non_topmed_nhomalt_fin_male","gnomad_gen_non_topmed_nhomalt_male","gnomad_gen_non_topmed_nhomalt_nfe","gnomad_gen_non_topmed_nhomalt_nfe_est","gnomad_gen_non_topmed_nhomalt_nfe_female","gnomad_gen_non_topmed_nhomalt_nfe_male","gnomad_gen_non_topmed_nhomalt_nfe_nwe","gnomad_gen_non_topmed_nhomalt_nfe_onf","gnomad_gen_non_topmed_nhomalt_nfe_seu","gnomad_gen_non_topmed_nhomalt_oth","gnomad_gen_non_topmed_nhomalt_oth_female","gnomad_gen_non_topmed_nhomalt_oth_male","gnomad_gen_non_topmed_nhomalt_popmax","gnomad_gen_non_topmed_nhomalt_raw","gnomad_gen_non_topmed_popmax","gnomad_gen_nonpar","gnomad_gen_pab_max","gnomad_gen_popmax","gnomad_gen_QD","gnomad_gen_ReadPosRankSum","gnomad_gen_rf_label","gnomad_gen_rf_negative_label","gnomad_gen_rf_positive_label","gnomad_gen_rf_tp_probability","gnomad_gen_rf_train","gnomad_gen_segdup","gnomad_gen_SOR","gnomad_gen_transmitted_singleton","gnomad_gen_variant_type","gnomad_gen_vep","gnomad_gen_VQSLOD","gnomad_gen_VQSR_culprit","gnomad_gen_VQSR_NEGATIVE_TRAIN_SITE","gnomad_gen_VQSR_POSITIVE_TRAIN_SITE","gnomad_gen_was_mixed"]
# fields = ["ab_hist_alt_bin_freq","AC","AC_afr","AC_afr_female","AC_afr_male","AC_amr","AC_amr_female","AC_amr_male","AC_asj","AC_asj_female","AC_asj_male","AC_eas","AC_eas_female","AC_eas_male","AC_female","AC_fin","AC_fin_female","AC_fin_male","AC_male","AC_nfe","AC_nfe_est","AC_nfe_female","AC_nfe_male","AC_nfe_nwe","AC_nfe_onf","AC_nfe_seu","AC_oth","AC_oth_female","AC_oth_male","AC_popmax","AC_raw","AF","AF_afr","AF_afr_female","AF_afr_male","AF_amr","AF_amr_female","AF_amr_male","AF_asj","AF_asj_female","AF_asj_male","AF_eas","AF_eas_female","AF_eas_male","AF_female","AF_fin","AF_fin_female","AF_fin_male","AF_male","AF_nfe","AF_nfe_est","AF_nfe_female","AF_nfe_male","AF_nfe_nwe","AF_nfe_onf","AF_nfe_seu","AF_oth","AF_oth_female","AF_oth_male","AF_popmax","AF_raw","age_hist_het_bin_freq","age_hist_het_n_larger","age_hist_het_n_smaller","age_hist_hom_bin_freq","age_hist_hom_n_larger","age_hist_hom_n_smaller","allele_type","AN","AN_afr","AN_afr_female","AN_afr_male","AN_amr","AN_amr_female","AN_amr_male","AN_asj","AN_asj_female","AN_asj_male","AN_eas","AN_eas_female","AN_eas_male","AN_female","AN_fin","AN_fin_female","AN_fin_male","AN_male","AN_nfe","AN_nfe_est","AN_nfe_female","AN_nfe_male","AN_nfe_nwe","AN_nfe_onf","AN_nfe_seu","AN_oth","AN_oth_female","AN_oth_male","AN_popmax","AN_raw","BaseQRankSum","ClippingRankSum","controls_AC","controls_AC_afr","controls_AC_afr_female","controls_AC_afr_male","controls_AC_amr","controls_AC_amr_female","controls_AC_amr_male","controls_AC_asj","controls_AC_asj_female","controls_AC_asj_male","controls_AC_eas","controls_AC_eas_female","controls_AC_eas_male","controls_AC_female","controls_AC_fin","controls_AC_fin_female","controls_AC_fin_male","controls_AC_male","controls_AC_nfe","controls_AC_nfe_est","controls_AC_nfe_female","controls_AC_nfe_male","controls_AC_nfe_nwe","controls_AC_nfe_onf","controls_AC_nfe_seu","controls_AC_oth","controls_AC_oth_female","controls_AC_oth_male","controls_AC_popmax","controls_AC_raw","controls_AF","controls_AF_afr","controls_AF_afr_female","controls_AF_afr_male","controls_AF_amr","controls_AF_amr_female","controls_AF_amr_male","controls_AF_asj","controls_AF_asj_female","controls_AF_asj_male","controls_AF_eas","controls_AF_eas_female","controls_AF_eas_male","controls_AF_female","controls_AF_fin","controls_AF_fin_female","controls_AF_fin_male","controls_AF_male","controls_AF_nfe","controls_AF_nfe_est","controls_AF_nfe_female","controls_AF_nfe_male","controls_AF_nfe_nwe","controls_AF_nfe_onf","controls_AF_nfe_seu","controls_AF_oth","controls_AF_oth_female","controls_AF_oth_male","controls_AF_popmax","controls_AF_raw","controls_AN","controls_AN_afr","controls_AN_afr_female","controls_AN_afr_male","controls_AN_amr","controls_AN_amr_female","controls_AN_amr_male","controls_AN_asj","controls_AN_asj_female","controls_AN_asj_male","controls_AN_eas","controls_AN_eas_female","controls_AN_eas_male","controls_AN_female","controls_AN_fin","controls_AN_fin_female","controls_AN_fin_male","controls_AN_male","controls_AN_nfe","controls_AN_nfe_est","controls_AN_nfe_female","controls_AN_nfe_male","controls_AN_nfe_nwe","controls_AN_nfe_onf","controls_AN_nfe_seu","controls_AN_oth","controls_AN_oth_female","controls_AN_oth_male","controls_AN_popmax","controls_AN_raw","controls_faf95","controls_faf95_afr","controls_faf95_amr","controls_faf95_eas","controls_faf95_nfe","controls_faf99","controls_faf99_afr","controls_faf99_amr","controls_faf99_eas","controls_faf99_nfe","controls_nhomalt","controls_nhomalt_afr","controls_nhomalt_afr_female","controls_nhomalt_afr_male","controls_nhomalt_amr","controls_nhomalt_amr_female","controls_nhomalt_amr_male","controls_nhomalt_asj","controls_nhomalt_asj_female","controls_nhomalt_asj_male","controls_nhomalt_eas","controls_nhomalt_eas_female","controls_nhomalt_eas_male","controls_nhomalt_female","controls_nhomalt_fin","controls_nhomalt_fin_female","controls_nhomalt_fin_male","controls_nhomalt_male","controls_nhomalt_nfe","controls_nhomalt_nfe_est","controls_nhomalt_nfe_female","controls_nhomalt_nfe_male","controls_nhomalt_nfe_nwe","controls_nhomalt_nfe_onf","controls_nhomalt_nfe_seu","controls_nhomalt_oth","controls_nhomalt_oth_female","controls_nhomalt_oth_male","controls_nhomalt_popmax","controls_nhomalt_raw","controls_popmax","decoy","DP","dp_hist_all_bin_freq","dp_hist_all_n_larger","dp_hist_alt_bin_freq","dp_hist_alt_n_larger","faf95","faf95_afr","faf95_amr","faf95_eas","faf95_nfe","faf99","faf99_afr","faf99_amr","faf99_eas","faf99_nfe","FS","gq_hist_all_bin_freq","gq_hist_alt_bin_freq","has_star","InbreedingCoeff","lcr","MQ","MQRankSum","n_alt_alleles","nhomalt","nhomalt_afr","nhomalt_afr_female","nhomalt_afr_male","nhomalt_amr","nhomalt_amr_female","nhomalt_amr_male","nhomalt_asj","nhomalt_asj_female","nhomalt_asj_male","nhomalt_eas","nhomalt_eas_female","nhomalt_eas_male","nhomalt_female","nhomalt_fin","nhomalt_fin_female","nhomalt_fin_male","nhomalt_male","nhomalt_nfe","nhomalt_nfe_est","nhomalt_nfe_female","nhomalt_nfe_male","nhomalt_nfe_nwe","nhomalt_nfe_onf","nhomalt_nfe_seu","nhomalt_oth","nhomalt_oth_female","nhomalt_oth_male","nhomalt_popmax","nhomalt_raw","non_neuro_AC","non_neuro_AC_afr","non_neuro_AC_afr_female","non_neuro_AC_afr_male","non_neuro_AC_amr","non_neuro_AC_amr_female","non_neuro_AC_amr_male","non_neuro_AC_asj","non_neuro_AC_asj_female","non_neuro_AC_asj_male","non_neuro_AC_eas","non_neuro_AC_eas_female","non_neuro_AC_eas_male","non_neuro_AC_female","non_neuro_AC_fin","non_neuro_AC_fin_female","non_neuro_AC_fin_male","non_neuro_AC_male","non_neuro_AC_nfe","non_neuro_AC_nfe_est","non_neuro_AC_nfe_female","non_neuro_AC_nfe_male","non_neuro_AC_nfe_nwe","non_neuro_AC_nfe_onf","non_neuro_AC_nfe_seu","non_neuro_AC_oth","non_neuro_AC_oth_female","non_neuro_AC_oth_male","non_neuro_AC_popmax","non_neuro_AC_raw","non_neuro_AF","non_neuro_AF_afr","non_neuro_AF_afr_female","non_neuro_AF_afr_male","non_neuro_AF_amr","non_neuro_AF_amr_female","non_neuro_AF_amr_male","non_neuro_AF_asj","non_neuro_AF_asj_female","non_neuro_AF_asj_male","non_neuro_AF_eas","non_neuro_AF_eas_female","non_neuro_AF_eas_male","non_neuro_AF_female","non_neuro_AF_fin","non_neuro_AF_fin_female","non_neuro_AF_fin_male","non_neuro_AF_male","non_neuro_AF_nfe","non_neuro_AF_nfe_est","non_neuro_AF_nfe_female","non_neuro_AF_nfe_male","non_neuro_AF_nfe_nwe","non_neuro_AF_nfe_onf","non_neuro_AF_nfe_seu","non_neuro_AF_oth","non_neuro_AF_oth_female","non_neuro_AF_oth_male","non_neuro_AF_popmax","non_neuro_AF_raw","non_neuro_AN","non_neuro_AN_afr","non_neuro_AN_afr_female","non_neuro_AN_afr_male","non_neuro_AN_amr","non_neuro_AN_amr_female","non_neuro_AN_amr_male","non_neuro_AN_asj","non_neuro_AN_asj_female","non_neuro_AN_asj_male","non_neuro_AN_eas","non_neuro_AN_eas_female","non_neuro_AN_eas_male","non_neuro_AN_female","non_neuro_AN_fin","non_neuro_AN_fin_female","non_neuro_AN_fin_male","non_neuro_AN_male","non_neuro_AN_nfe","non_neuro_AN_nfe_est","non_neuro_AN_nfe_female","non_neuro_AN_nfe_male","non_neuro_AN_nfe_nwe","non_neuro_AN_nfe_onf","non_neuro_AN_nfe_seu","non_neuro_AN_oth","non_neuro_AN_oth_female","non_neuro_AN_oth_male","non_neuro_AN_popmax","non_neuro_AN_raw","non_neuro_faf95","non_neuro_faf95_afr","non_neuro_faf95_amr","non_neuro_faf95_eas","non_neuro_faf95_nfe","non_neuro_faf99","non_neuro_faf99_afr","non_neuro_faf99_amr","non_neuro_faf99_eas","non_neuro_faf99_nfe","non_neuro_nhomalt","non_neuro_nhomalt_afr","non_neuro_nhomalt_afr_female","non_neuro_nhomalt_afr_male","non_neuro_nhomalt_amr","non_neuro_nhomalt_amr_female","non_neuro_nhomalt_amr_male","non_neuro_nhomalt_asj","non_neuro_nhomalt_asj_female","non_neuro_nhomalt_asj_male","non_neuro_nhomalt_eas","non_neuro_nhomalt_eas_female","non_neuro_nhomalt_eas_male","non_neuro_nhomalt_female","non_neuro_nhomalt_fin","non_neuro_nhomalt_fin_female","non_neuro_nhomalt_fin_male","non_neuro_nhomalt_male","non_neuro_nhomalt_nfe","non_neuro_nhomalt_nfe_est","non_neuro_nhomalt_nfe_female","non_neuro_nhomalt_nfe_male","non_neuro_nhomalt_nfe_nwe","non_neuro_nhomalt_nfe_onf","non_neuro_nhomalt_nfe_seu","non_neuro_nhomalt_oth","non_neuro_nhomalt_oth_female","non_neuro_nhomalt_oth_male","non_neuro_nhomalt_popmax","non_neuro_nhomalt_raw","non_neuro_popmax","non_topmed_AC","non_topmed_AC_afr","non_topmed_AC_afr_female","non_topmed_AC_afr_male","non_topmed_AC_amr","non_topmed_AC_amr_female","non_topmed_AC_amr_male","non_topmed_AC_asj","non_topmed_AC_asj_female","non_topmed_AC_asj_male","non_topmed_AC_eas","non_topmed_AC_eas_female","non_topmed_AC_eas_male","non_topmed_AC_female","non_topmed_AC_fin","non_topmed_AC_fin_female","non_topmed_AC_fin_male","non_topmed_AC_male","non_topmed_AC_nfe","non_topmed_AC_nfe_est","non_topmed_AC_nfe_female","non_topmed_AC_nfe_male","non_topmed_AC_nfe_nwe","non_topmed_AC_nfe_onf","non_topmed_AC_nfe_seu","non_topmed_AC_oth","non_topmed_AC_oth_female","non_topmed_AC_oth_male","non_topmed_AC_popmax","non_topmed_AC_raw","non_topmed_AF","non_topmed_AF_afr","non_topmed_AF_afr_female","non_topmed_AF_afr_male","non_topmed_AF_amr","non_topmed_AF_amr_female","non_topmed_AF_amr_male","non_topmed_AF_asj","non_topmed_AF_asj_female","non_topmed_AF_asj_male","non_topmed_AF_eas","non_topmed_AF_eas_female","non_topmed_AF_eas_male","non_topmed_AF_female","non_topmed_AF_fin","non_topmed_AF_fin_female","non_topmed_AF_fin_male","non_topmed_AF_male","non_topmed_AF_nfe","non_topmed_AF_nfe_est","non_topmed_AF_nfe_female","non_topmed_AF_nfe_male","non_topmed_AF_nfe_nwe","non_topmed_AF_nfe_onf","non_topmed_AF_nfe_seu","non_topmed_AF_oth","non_topmed_AF_oth_female","non_topmed_AF_oth_male","non_topmed_AF_popmax","non_topmed_AF_raw","non_topmed_AN","non_topmed_AN_afr","non_topmed_AN_afr_female","non_topmed_AN_afr_male","non_topmed_AN_amr","non_topmed_AN_amr_female","non_topmed_AN_amr_male","non_topmed_AN_asj","non_topmed_AN_asj_female","non_topmed_AN_asj_male","non_topmed_AN_eas","non_topmed_AN_eas_female","non_topmed_AN_eas_male","non_topmed_AN_female","non_topmed_AN_fin","non_topmed_AN_fin_female","non_topmed_AN_fin_male","non_topmed_AN_male","non_topmed_AN_nfe","non_topmed_AN_nfe_est","non_topmed_AN_nfe_female","non_topmed_AN_nfe_male","non_topmed_AN_nfe_nwe","non_topmed_AN_nfe_onf","non_topmed_AN_nfe_seu","non_topmed_AN_oth","non_topmed_AN_oth_female","non_topmed_AN_oth_male","non_topmed_AN_popmax","non_topmed_AN_raw","non_topmed_faf95","non_topmed_faf95_afr","non_topmed_faf95_amr","non_topmed_faf95_eas","non_topmed_faf95_nfe","non_topmed_faf99","non_topmed_faf99_afr","non_topmed_faf99_amr","non_topmed_faf99_eas","non_topmed_faf99_nfe","non_topmed_nhomalt","non_topmed_nhomalt_afr","non_topmed_nhomalt_afr_female","non_topmed_nhomalt_afr_male","non_topmed_nhomalt_amr","non_topmed_nhomalt_amr_female","non_topmed_nhomalt_amr_male","non_topmed_nhomalt_asj","non_topmed_nhomalt_asj_female","non_topmed_nhomalt_asj_male","non_topmed_nhomalt_eas","non_topmed_nhomalt_eas_female","non_topmed_nhomalt_eas_male","non_topmed_nhomalt_female","non_topmed_nhomalt_fin","non_topmed_nhomalt_fin_female","non_topmed_nhomalt_fin_male","non_topmed_nhomalt_male","non_topmed_nhomalt_nfe","non_topmed_nhomalt_nfe_est","non_topmed_nhomalt_nfe_female","non_topmed_nhomalt_nfe_male","non_topmed_nhomalt_nfe_nwe","non_topmed_nhomalt_nfe_onf","non_topmed_nhomalt_nfe_seu","non_topmed_nhomalt_oth","non_topmed_nhomalt_oth_female","non_topmed_nhomalt_oth_male","non_topmed_nhomalt_popmax","non_topmed_nhomalt_raw","non_topmed_popmax","nonpar","pab_max","popmax","QD","ReadPosRankSum","rf_label","rf_negative_label","rf_positive_label","rf_tp_probability","rf_train","segdup","SOR","transmitted_singleton","variant_type","vep","VQSLOD","VQSR_culprit","VQSR_NEGATIVE_TRAIN_SITE","VQSR_POSITIVE_TRAIN_SITE","was_mixed",]
# ops=["first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first","first"]
